searchData={"content_type":"text/markdown","items":[{"doc":"`.fit` file decoder. See `ExtFit.Decode` module for more details and usage.\n\nIt's still in alpha-release and there's a slim chance that the format of returned\nstructs will change but if possible, will be avoided.\n\nCurrently used FIT profile can be seen in `ExtFit.Profile.Types` file.","ref":"ExtFit.html","title":"ExtFit","type":"module"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `ext_fit` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ext_fit, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"ExtFit.html#module-installation","title":"Installation - ExtFit","type":"module"},{"doc":"```elixir\n{:ok, records} =\n  \"my-file.fit\"\n  |> File.read!()\n  |> ExtFit.Decode.decode()\n\n# print first record\nhd(record)\n```\n\nThe docs can be found at  .\n\nFIT structs are very large, you might want to take a look at\n[examples](https://github.com/arathunku/ext_fit/tree/main/examples) first!\n\nhttps://github.com/arathunku/ext_fit/assets/749393/4c16c3ff-ba47-472b-9323-c9285842c2a8\n\n(may not be visible on hexdocs, see [GitHub README](https://github.com/arathunku/ext_fit/tree/main?tab=readme-ov-file#usage))","ref":"ExtFit.html#module-usage","title":"Usage - ExtFit","type":"module"},{"doc":"Before contributing to this project, please read the CONTRIBUTING.md.","ref":"ExtFit.html#module-contributing","title":"Contributing - ExtFit","type":"module"},{"doc":"Copyright © 2024 Michal Forys\n\nThis project is licensed under the MIT license.","ref":"ExtFit.html#module-license","title":"License - ExtFit","type":"module"},{"doc":"Chunk data struct with index for each record, its offset in the file and size.","ref":"ExtFit.Chunk.html","title":"ExtFit.Chunk","type":"module"},{"doc":"","ref":"ExtFit.Chunk.html#t:t/0","title":"ExtFit.Chunk.t/0","type":"type"},{"doc":"Decodes FIT file into a list of records. If binary data has multiple FIT files\nstiched together it will process them all.\n\nSee `decode/2` for details.","ref":"ExtFit.Decode.html","title":"ExtFit.Decode","type":"module"},{"doc":"See `decode/2` for details","ref":"ExtFit.Decode.html#decode/1","title":"ExtFit.Decode.decode/1","type":"function"},{"doc":"Decodes FIT binary data.\n\nEach record is one of the following types:\n\n  - `ExtFit.Record.FitHeader` - FIT file header\n  - `ExtFit.Record.FitDefinition` - definition message\n  - `ExtFit.Record.FitData` - data message\n  - `ExtFit.Record.FitCrc` - CRC information encoded in the file\n\nDecode accepts the following options:\n\n  - `expand_components` - (default: `true`) - whether to expand components into separate fields\n  - `processors` - (default: `ExtFit.Processor.DefaultProcessor` and `ExtFit.Processor.StandardUnitsProcessor`) -\n     list of processors to apply to each record","ref":"ExtFit.Decode.html#decode/2","title":"ExtFit.Decode.decode/2","type":"function"},{"doc":"iex> alias ExtFit.Record.{FitHeader, FitDefinition, FitData}\n    iex> alias ExtFit.Types.{FieldData, Field}\n    iex> {:ok, records} = ExtFit.Decode.decode(File.read!(\"test/support/files/2023-06-04-garmin-955-running.fit\"))\n    iex> # Every FIT file starts with a FitHeader\n    iex> %FitHeader{body_size: 409401} = hd(records)\n    iex> # Then is followed by FileId definition and data\n    iex> %FitData{\n    ...>   def_mesg: %FitDefinition{mesg_type: %ExtFit.Profile.Messages.FileId{}},\n    ...>   fields: [\n    ...>     %FieldData{field: %Field{name: :serial_number}, value: 3442024736}\n    ...>     | _rest_of_fields\n    ...>   ]\n    ...> } = Enum.at(records, 2)","ref":"ExtFit.Decode.html#decode/2-examples","title":"Examples - ExtFit.Decode.decode/2","type":"function"},{"doc":"See `decode/2` for details. `decode!` raises an error in case decoding fails.","ref":"ExtFit.Decode.html#decode!/2","title":"ExtFit.Decode.decode!/2","type":"function"},{"doc":"Helper mExtFit.Fieldethods for working with fields of various types - `t:ExtFit.Field.field/0`","ref":"ExtFit.Field.html","title":"ExtFit.Field","type":"module"},{"doc":"Recursively searches for base type within a field","ref":"ExtFit.Field.html#base_type/1","title":"ExtFit.Field.base_type/1","type":"function"},{"doc":"Returns field's name. If field is known it will return its atom name, if field is unknown\nit returns `\"unknown_#{num}\"`.","ref":"ExtFit.Field.html#name/1","title":"ExtFit.Field.name/1","type":"function"},{"doc":"Check if field is unknown","ref":"ExtFit.Field.html#unknown?/1","title":"ExtFit.Field.unknown?/1","type":"function"},{"doc":"","ref":"ExtFit.Field.html#t:field/0","title":"ExtFit.Field.field/0","type":"type"},{"doc":"Defines behaviour for processing records and field data.","ref":"ExtFit.Processor.html","title":"ExtFit.Processor","type":"behaviour"},{"doc":"Called for each field data.","ref":"ExtFit.Processor.html#c:process_field_data/1","title":"ExtFit.Processor.process_field_data/1","type":"callback"},{"doc":"Called for each record.","ref":"ExtFit.Processor.html#c:process_record/1","title":"ExtFit.Processor.process_record/1","type":"callback"},{"doc":"","ref":"ExtFit.Processor.html#t:field_data/0","title":"ExtFit.Processor.field_data/0","type":"type"},{"doc":"","ref":"ExtFit.Processor.html#t:record/0","title":"ExtFit.Processor.record/0","type":"type"},{"doc":"Inspects and prints information about each processed record. Helpul for debugging. Disabled by default.","ref":"ExtFit.Processor.DebugProcessor.html","title":"ExtFit.Processor.DebugProcessor","type":"module"},{"doc":"","ref":"ExtFit.Processor.DebugProcessor.html#process_field_data/1","title":"ExtFit.Processor.DebugProcessor.process_field_data/1","type":"function"},{"doc":"","ref":"ExtFit.Processor.DebugProcessor.html#process_record/1","title":"ExtFit.Processor.DebugProcessor.process_record/1","type":"function"},{"doc":"Converts some of FIT types into more useful and standard units.\n\n* Garmin \"timestamps\" into Elixir DateTime\n* Garmin \"local_timestamps\" into Elixir NaiveDateTime\n\nEnabled by default.","ref":"ExtFit.Processor.DefaultProcessor.html","title":"ExtFit.Processor.DefaultProcessor","type":"module"},{"doc":"","ref":"ExtFit.Processor.DefaultProcessor.html#process_field_data/1","title":"ExtFit.Processor.DefaultProcessor.process_field_data/1","type":"function"},{"doc":"","ref":"ExtFit.Processor.DefaultProcessor.html#process_record/1","title":"ExtFit.Processor.DefaultProcessor.process_record/1","type":"function"},{"doc":"Additional units processor for nicer out of box DX when working with FIT files.\n\n* `semicircles` to `deg`\n\nEnabled by default.","ref":"ExtFit.Processor.StandardUnitsProcessor.html","title":"ExtFit.Processor.StandardUnitsProcessor","type":"module"},{"doc":"","ref":"ExtFit.Processor.StandardUnitsProcessor.html#process_field_data/1","title":"ExtFit.Processor.StandardUnitsProcessor.process_field_data/1","type":"function"},{"doc":"","ref":"ExtFit.Processor.StandardUnitsProcessor.html#process_record/1","title":"ExtFit.Processor.StandardUnitsProcessor.process_record/1","type":"function"},{"doc":"FIT Messages for profile from version: 21.126.00","ref":"ExtFit.Profile.Messages.html","title":"ExtFit.Profile.Messages","type":"module"},{"doc":"Get message by name","ref":"ExtFit.Profile.Messages.html#by_name/1","title":"ExtFit.Profile.Messages.by_name/1","type":"function"},{"doc":"Get message by its number","ref":"ExtFit.Profile.Messages.html#by_num/1","title":"ExtFit.Profile.Messages.by_num/1","type":"function"},{"doc":"Get field. Supports only :timestamp field for now which is shared between all messages.","ref":"ExtFit.Profile.Messages.html#field/1","title":"ExtFit.Profile.Messages.field/1","type":"function"},{"doc":"Get field num for specific message.","ref":"ExtFit.Profile.Messages.html#field_num/1","title":"ExtFit.Profile.Messages.field_num/1","type":"function"},{"doc":"Returns all known messages","ref":"ExtFit.Profile.Messages.html#messages/0","title":"ExtFit.Profile.Messages.messages/0","type":"function"},{"doc":"Message: `:accelerometer_data` identified by num=165","ref":"ExtFit.Profile.Messages.AccelerometerData.html","title":"ExtFit.Profile.Messages.AccelerometerData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| sample_time_offset | uint16 | 1 |  |  | ms | true |\n| accel_x | uint16 | 2 |  |  | counts | true |\n| accel_y | uint16 | 3 |  |  | counts | true |\n| accel_z | uint16 | 4 |  |  | counts | true |\n| calibrated_accel_x | float32 | 5 |  |  | g | true |\n| calibrated_accel_y | float32 | 6 |  |  | g | true |\n| calibrated_accel_z | float32 | 7 |  |  | g | true |\n| compressed_calibrated_accel_x | sint16 | 8 |  |  | mG | true |\n| compressed_calibrated_accel_y | sint16 | 9 |  |  | mG | true |\n| compressed_calibrated_accel_z | sint16 | 10 |  |  | mG | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.AccelerometerData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.AccelerometerData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.AccelerometerData.html#t:t/0","title":"ExtFit.Profile.Messages.AccelerometerData.t/0","type":"type"},{"doc":"Message: `:activity` identified by num=34","ref":"ExtFit.Profile.Messages.Activity.html","title":"ExtFit.Profile.Messages.Activity","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| total_timer_time | uint32 | 0 | 1000 |  | s | false |\n| num_sessions | uint16 | 1 |  |  |  | false |\n| type | activity | 2 |  |  |  | false |\n| event | event | 3 |  |  |  | false |\n| event_type | event_type | 4 |  |  |  | false |\n| local_timestamp | local_date_time | 5 |  |  |  | false |\n| event_group | uint8 | 6 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Activity.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Activity","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Activity.html#t:t/0","title":"ExtFit.Profile.Messages.Activity.t/0","type":"type"},{"doc":"Message: `:ant_channel_id` identified by num=82","ref":"ExtFit.Profile.Messages.AntChannelId.html","title":"ExtFit.Profile.Messages.AntChannelId","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| channel_number | uint8 | 0 |  |  |  | false |\n| device_type | uint8z | 1 |  |  |  | false |\n| device_number | uint16z | 2 |  |  |  | false |\n| transmission_type | uint8z | 3 |  |  |  | false |\n| device_index | device_index | 4 |  |  |  | false |","ref":"ExtFit.Profile.Messages.AntChannelId.html#module-fields","title":"Fields - ExtFit.Profile.Messages.AntChannelId","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.AntChannelId.html#t:t/0","title":"ExtFit.Profile.Messages.AntChannelId.t/0","type":"type"},{"doc":"Message: `:ant_rx` identified by num=80","ref":"ExtFit.Profile.Messages.AntRx.html","title":"ExtFit.Profile.Messages.AntRx","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| fractional_timestamp | uint16 | 0 | 32768 |  | s | false |\n| mesg_id | byte | 1 |  |  |  | false |\n| mesg_data | byte | 2 |  |  |  | true |\n| channel_number | uint8 | 3 |  |  |  | false |\n| data | byte | 4 |  |  |  | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.AntRx.html#module-fields","title":"Fields - ExtFit.Profile.Messages.AntRx","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.AntRx.html#t:t/0","title":"ExtFit.Profile.Messages.AntRx.t/0","type":"type"},{"doc":"Message: `:ant_tx` identified by num=81","ref":"ExtFit.Profile.Messages.AntTx.html","title":"ExtFit.Profile.Messages.AntTx","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| fractional_timestamp | uint16 | 0 | 32768 |  | s | false |\n| mesg_id | byte | 1 |  |  |  | false |\n| mesg_data | byte | 2 |  |  |  | true |\n| channel_number | uint8 | 3 |  |  |  | false |\n| data | byte | 4 |  |  |  | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.AntTx.html#module-fields","title":"Fields - ExtFit.Profile.Messages.AntTx","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.AntTx.html#t:t/0","title":"ExtFit.Profile.Messages.AntTx.t/0","type":"type"},{"doc":"Message: `:aviation_attitude` identified by num=178","ref":"ExtFit.Profile.Messages.AviationAttitude.html","title":"ExtFit.Profile.Messages.AviationAttitude","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| system_time | uint32 | 1 |  |  | ms | true |\n| pitch | sint16 | 2 | 10430.38 |  | radians | true |\n| roll | sint16 | 3 | 10430.38 |  | radians | true |\n| accel_lateral | sint16 | 4 | 100 |  | m/s^2 | true |\n| accel_normal | sint16 | 5 | 100 |  | m/s^2 | true |\n| turn_rate | sint16 | 6 | 1024 |  | radians/second | true |\n| stage | attitude_stage | 7 |  |  |  | true |\n| attitude_stage_complete | uint8 | 8 |  |  | % | true |\n| track | uint16 | 9 | 10430.38 |  | radians | true |\n| validity | attitude_validity | 10 |  |  |  | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.AviationAttitude.html#module-fields","title":"Fields - ExtFit.Profile.Messages.AviationAttitude","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.AviationAttitude.html#t:t/0","title":"ExtFit.Profile.Messages.AviationAttitude.t/0","type":"type"},{"doc":"Message: `:barometer_data` identified by num=209","ref":"ExtFit.Profile.Messages.BarometerData.html","title":"ExtFit.Profile.Messages.BarometerData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| sample_time_offset | uint16 | 1 |  |  | ms | true |\n| baro_pres | uint32 | 2 |  |  | Pa | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.BarometerData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.BarometerData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.BarometerData.html#t:t/0","title":"ExtFit.Profile.Messages.BarometerData.t/0","type":"type"},{"doc":"Message: `:beat_intervals` identified by num=290","ref":"ExtFit.Profile.Messages.BeatIntervals.html","title":"ExtFit.Profile.Messages.BeatIntervals","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| time | uint16 | 1 |  |  | ms | true |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.BeatIntervals.html#module-fields","title":"Fields - ExtFit.Profile.Messages.BeatIntervals","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.BeatIntervals.html#t:t/0","title":"ExtFit.Profile.Messages.BeatIntervals.t/0","type":"type"},{"doc":"Message: `:bike_profile` identified by num=6","ref":"ExtFit.Profile.Messages.BikeProfile.html","title":"ExtFit.Profile.Messages.BikeProfile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| name | string | 0 |  |  |  | false |\n| sport | sport | 1 |  |  |  | false |\n| sub_sport | sub_sport | 2 |  |  |  | false |\n| odometer | uint32 | 3 | 100 |  | m | false |\n| bike_spd_ant_id | uint16z | 4 |  |  |  | false |\n| bike_cad_ant_id | uint16z | 5 |  |  |  | false |\n| bike_spdcad_ant_id | uint16z | 6 |  |  |  | false |\n| bike_power_ant_id | uint16z | 7 |  |  |  | false |\n| custom_wheelsize | uint16 | 8 | 1000 |  | m | false |\n| auto_wheelsize | uint16 | 9 | 1000 |  | m | false |\n| bike_weight | uint16 | 10 | 10 |  | kg | false |\n| power_cal_factor | uint16 | 11 | 10 |  | % | false |\n| auto_wheel_cal | bool | 12 |  |  |  | false |\n| auto_power_zero | bool | 13 |  |  |  | false |\n| id | uint8 | 14 |  |  |  | false |\n| spd_enabled | bool | 15 |  |  |  | false |\n| cad_enabled | bool | 16 |  |  |  | false |\n| spdcad_enabled | bool | 17 |  |  |  | false |\n| power_enabled | bool | 18 |  |  |  | false |\n| crank_length | uint8 | 19 | 2 | -110 | mm | false |\n| enabled | bool | 20 |  |  |  | false |\n| bike_spd_ant_id_trans_type | uint8z | 21 |  |  |  | false |\n| bike_cad_ant_id_trans_type | uint8z | 22 |  |  |  | false |\n| bike_spdcad_ant_id_trans_type | uint8z | 23 |  |  |  | false |\n| bike_power_ant_id_trans_type | uint8z | 24 |  |  |  | false |\n| odometer_rollover | uint8 | 37 |  |  |  | false |\n| front_gear_num | uint8z | 38 |  |  |  | false |\n| front_gear | uint8z | 39 |  |  |  | true |\n| rear_gear_num | uint8z | 40 |  |  |  | false |\n| rear_gear | uint8z | 41 |  |  |  | true |\n| shimano_di2_enabled | bool | 44 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.BikeProfile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.BikeProfile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.BikeProfile.html#t:t/0","title":"ExtFit.Profile.Messages.BikeProfile.t/0","type":"type"},{"doc":"Message: `:blood_pressure` identified by num=51","ref":"ExtFit.Profile.Messages.BloodPressure.html","title":"ExtFit.Profile.Messages.BloodPressure","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| systolic_pressure | uint16 | 0 |  |  | mmHg | false |\n| diastolic_pressure | uint16 | 1 |  |  | mmHg | false |\n| mean_arterial_pressure | uint16 | 2 |  |  | mmHg | false |\n| map_3_sample_mean | uint16 | 3 |  |  | mmHg | false |\n| map_morning_values | uint16 | 4 |  |  | mmHg | false |\n| map_evening_values | uint16 | 5 |  |  | mmHg | false |\n| heart_rate | uint8 | 6 |  |  | bpm | false |\n| heart_rate_type | hr_type | 7 |  |  |  | false |\n| status | bp_status | 8 |  |  |  | false |\n| user_profile_index | message_index | 9 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.BloodPressure.html#module-fields","title":"Fields - ExtFit.Profile.Messages.BloodPressure","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.BloodPressure.html#t:t/0","title":"ExtFit.Profile.Messages.BloodPressure.t/0","type":"type"},{"doc":"Message: `:cadence_zone` identified by num=131","ref":"ExtFit.Profile.Messages.CadenceZone.html","title":"ExtFit.Profile.Messages.CadenceZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| high_value | uint8 | 0 |  |  | rpm | false |\n| name | string | 1 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.CadenceZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.CadenceZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.CadenceZone.html#t:t/0","title":"ExtFit.Profile.Messages.CadenceZone.t/0","type":"type"},{"doc":"Message: `:camera_event` identified by num=161","ref":"ExtFit.Profile.Messages.CameraEvent.html","title":"ExtFit.Profile.Messages.CameraEvent","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| camera_event_type | camera_event_type | 1 |  |  |  | false |\n| camera_file_uuid | string | 2 |  |  |  | false |\n| camera_orientation | camera_orientation_type | 3 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.CameraEvent.html#module-fields","title":"Fields - ExtFit.Profile.Messages.CameraEvent","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.CameraEvent.html#t:t/0","title":"ExtFit.Profile.Messages.CameraEvent.t/0","type":"type"},{"doc":"Message: `:capabilities` identified by num=1","ref":"ExtFit.Profile.Messages.Capabilities.html","title":"ExtFit.Profile.Messages.Capabilities","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| languages | uint8z | 0 |  |  |  | true |\n| sports | sport_bits_0 | 1 |  |  |  | true |\n| workouts_supported | workout_capabilities | 21 |  |  |  | false |\n| connectivity_supported | connectivity_capabilities | 23 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Capabilities.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Capabilities","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Capabilities.html#t:t/0","title":"ExtFit.Profile.Messages.Capabilities.t/0","type":"type"},{"doc":"Message: `:climb_pro` identified by num=317","ref":"ExtFit.Profile.Messages.ClimbPro.html","title":"ExtFit.Profile.Messages.ClimbPro","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| position_lat | sint32 | 0 |  |  | semicircles | false |\n| position_long | sint32 | 1 |  |  | semicircles | false |\n| climb_pro_event | climb_pro_event | 2 |  |  |  | false |\n| climb_number | uint16 | 3 |  |  |  | false |\n| climb_category | uint8 | 4 |  |  |  | false |\n| current_dist | float32 | 5 |  |  | m | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.ClimbPro.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ClimbPro","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ClimbPro.html#t:t/0","title":"ExtFit.Profile.Messages.ClimbPro.t/0","type":"type"},{"doc":"Message: `:connectivity` identified by num=127","ref":"ExtFit.Profile.Messages.Connectivity.html","title":"ExtFit.Profile.Messages.Connectivity","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| bluetooth_enabled | bool | 0 |  |  |  | false |\n| bluetooth_le_enabled | bool | 1 |  |  |  | false |\n| ant_enabled | bool | 2 |  |  |  | false |\n| name | string | 3 |  |  |  | false |\n| live_tracking_enabled | bool | 4 |  |  |  | false |\n| weather_conditions_enabled | bool | 5 |  |  |  | false |\n| weather_alerts_enabled | bool | 6 |  |  |  | false |\n| auto_activity_upload_enabled | bool | 7 |  |  |  | false |\n| course_download_enabled | bool | 8 |  |  |  | false |\n| workout_download_enabled | bool | 9 |  |  |  | false |\n| gps_ephemeris_download_enabled | bool | 10 |  |  |  | false |\n| incident_detection_enabled | bool | 11 |  |  |  | false |\n| grouptrack_enabled | bool | 12 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Connectivity.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Connectivity","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Connectivity.html#t:t/0","title":"ExtFit.Profile.Messages.Connectivity.t/0","type":"type"},{"doc":"Message: `:course` identified by num=31","ref":"ExtFit.Profile.Messages.Course.html","title":"ExtFit.Profile.Messages.Course","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sport | sport | 4 |  |  |  | false |\n| name | string | 5 |  |  |  | false |\n| capabilities | course_capabilities | 6 |  |  |  | false |\n| sub_sport | sub_sport | 7 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Course.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Course","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Course.html#t:t/0","title":"ExtFit.Profile.Messages.Course.t/0","type":"type"},{"doc":"Message: `:course_point` identified by num=32","ref":"ExtFit.Profile.Messages.CoursePoint.html","title":"ExtFit.Profile.Messages.CoursePoint","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp | date_time | 1 |  |  |  | false |\n| position_lat | sint32 | 2 |  |  | semicircles | false |\n| position_long | sint32 | 3 |  |  | semicircles | false |\n| distance | uint32 | 4 | 100 |  | m | false |\n| type | course_point | 5 |  |  |  | false |\n| name | string | 6 |  |  |  | false |\n| favorite | bool | 8 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.CoursePoint.html#module-fields","title":"Fields - ExtFit.Profile.Messages.CoursePoint","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.CoursePoint.html#t:t/0","title":"ExtFit.Profile.Messages.CoursePoint.t/0","type":"type"},{"doc":"Message: `:developer_data_id` identified by num=207","ref":"ExtFit.Profile.Messages.DeveloperDataId.html","title":"ExtFit.Profile.Messages.DeveloperDataId","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| developer_id | byte | 0 |  |  |  | true |\n| application_id | byte | 1 |  |  |  | true |\n| manufacturer_id | manufacturer | 2 |  |  |  | false |\n| developer_data_index | uint8 | 3 |  |  |  | false |\n| application_version | uint32 | 4 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DeveloperDataId.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DeveloperDataId","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DeveloperDataId.html#t:t/0","title":"ExtFit.Profile.Messages.DeveloperDataId.t/0","type":"type"},{"doc":"Message: `:device_aux_battery_info` identified by num=375","ref":"ExtFit.Profile.Messages.DeviceAuxBatteryInfo.html","title":"ExtFit.Profile.Messages.DeviceAuxBatteryInfo","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| device_index | device_index | 0 |  |  |  | false |\n| battery_voltage | uint16 | 1 | 256 |  | V | false |\n| battery_status | battery_status | 2 |  |  |  | false |\n| battery_identifier | uint8 | 3 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DeviceAuxBatteryInfo.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DeviceAuxBatteryInfo","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DeviceAuxBatteryInfo.html#t:t/0","title":"ExtFit.Profile.Messages.DeviceAuxBatteryInfo.t/0","type":"type"},{"doc":"Message: `:device_info` identified by num=23","ref":"ExtFit.Profile.Messages.DeviceInfo.html","title":"ExtFit.Profile.Messages.DeviceInfo","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| device_index | device_index | 0 |  |  |  | false |\n| device_type | uint8 | 1 |  |  |  | false |\n| manufacturer | manufacturer | 2 |  |  |  | false |\n| serial_number | uint32z | 3 |  |  |  | false |\n| product | uint16 | 4 |  |  |  | false |\n| software_version | uint16 | 5 | 100 |  |  | false |\n| hardware_version | uint8 | 6 |  |  |  | false |\n| cum_operating_time | uint32 | 7 |  |  | s | false |\n| battery_voltage | uint16 | 10 | 256 |  | V | false |\n| battery_status | battery_status | 11 |  |  |  | false |\n| sensor_position | body_location | 18 |  |  |  | false |\n| descriptor | string | 19 |  |  |  | false |\n| ant_transmission_type | uint8z | 20 |  |  |  | false |\n| ant_device_number | uint16z | 21 |  |  |  | false |\n| ant_network | ant_network | 22 |  |  |  | false |\n| source_type | source_type | 25 |  |  |  | false |\n| product_name | string | 27 |  |  |  | false |\n| battery_level | uint8 | 32 |  |  | % | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.DeviceInfo.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DeviceInfo","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DeviceInfo.html#t:t/0","title":"ExtFit.Profile.Messages.DeviceInfo.t/0","type":"type"},{"doc":"Message: `:device_settings` identified by num=2","ref":"ExtFit.Profile.Messages.DeviceSettings.html","title":"ExtFit.Profile.Messages.DeviceSettings","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| active_time_zone | uint8 | 0 |  |  |  | false |\n| utc_offset | uint32 | 1 |  |  |  | false |\n| time_offset | uint32 | 2 |  |  | s | true |\n| time_mode | time_mode | 4 |  |  |  | true |\n| time_zone_offset | sint8 | 5 | 4 |  | hr | true |\n| backlight_mode | backlight_mode | 12 |  |  |  | false |\n| activity_tracker_enabled | bool | 36 |  |  |  | false |\n| clock_time | date_time | 39 |  |  |  | false |\n| pages_enabled | uint16 | 40 |  |  |  | true |\n| move_alert_enabled | bool | 46 |  |  |  | false |\n| date_mode | date_mode | 47 |  |  |  | false |\n| display_orientation | display_orientation | 55 |  |  |  | false |\n| mounting_side | side | 56 |  |  |  | false |\n| default_page | uint16 | 57 |  |  |  | true |\n| autosync_min_steps | uint16 | 58 |  |  | steps | false |\n| autosync_min_time | uint16 | 59 |  |  | minutes | false |\n| lactate_threshold_autodetect_enabled | bool | 80 |  |  |  | false |\n| ble_auto_upload_enabled | bool | 86 |  |  |  | false |\n| auto_sync_frequency | auto_sync_frequency | 89 |  |  |  | false |\n| auto_activity_detect | auto_activity_detect | 90 |  |  |  | false |\n| number_of_screens | uint8 | 94 |  |  |  | false |\n| smart_notification_display_orientation | display_orientation | 95 |  |  |  | false |\n| tap_interface | switch | 134 |  |  |  | false |\n| tap_sensitivity | tap_sensitivity | 174 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DeviceSettings.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DeviceSettings","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DeviceSettings.html#t:t/0","title":"ExtFit.Profile.Messages.DeviceSettings.t/0","type":"type"},{"doc":"Message: `:dive_alarm` identified by num=262","ref":"ExtFit.Profile.Messages.DiveAlarm.html","title":"ExtFit.Profile.Messages.DiveAlarm","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| depth | uint32 | 0 | 1000 |  | m | false |\n| time | sint32 | 1 | 1 |  | s | false |\n| enabled | bool | 2 |  |  |  | false |\n| alarm_type | dive_alarm_type | 3 |  |  |  | false |\n| sound | tone | 4 |  |  |  | false |\n| dive_types | sub_sport | 5 |  |  |  | true |\n| id | uint32 | 6 |  |  |  | false |\n| popup_enabled | bool | 7 |  |  |  | false |\n| trigger_on_descent | bool | 8 |  |  |  | false |\n| trigger_on_ascent | bool | 9 |  |  |  | false |\n| repeating | bool | 10 |  |  |  | false |\n| speed | sint32 | 11 | 1000 |  | mps | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DiveAlarm.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DiveAlarm","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DiveAlarm.html#t:t/0","title":"ExtFit.Profile.Messages.DiveAlarm.t/0","type":"type"},{"doc":"Message: `:dive_apnea_alarm` identified by num=393","ref":"ExtFit.Profile.Messages.DiveApneaAlarm.html","title":"ExtFit.Profile.Messages.DiveApneaAlarm","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| depth | uint32 | 0 | 1000 |  | m | false |\n| time | sint32 | 1 | 1 |  | s | false |\n| enabled | bool | 2 |  |  |  | false |\n| alarm_type | dive_alarm_type | 3 |  |  |  | false |\n| sound | tone | 4 |  |  |  | false |\n| dive_types | sub_sport | 5 |  |  |  | true |\n| id | uint32 | 6 |  |  |  | false |\n| popup_enabled | bool | 7 |  |  |  | false |\n| trigger_on_descent | bool | 8 |  |  |  | false |\n| trigger_on_ascent | bool | 9 |  |  |  | false |\n| repeating | bool | 10 |  |  |  | false |\n| speed | sint32 | 11 | 1000 |  | mps | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DiveApneaAlarm.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DiveApneaAlarm","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DiveApneaAlarm.html#t:t/0","title":"ExtFit.Profile.Messages.DiveApneaAlarm.t/0","type":"type"},{"doc":"Message: `:dive_gas` identified by num=259","ref":"ExtFit.Profile.Messages.DiveGas.html","title":"ExtFit.Profile.Messages.DiveGas","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| helium_content | uint8 | 0 |  |  | percent | false |\n| oxygen_content | uint8 | 1 |  |  | percent | false |\n| status | dive_gas_status | 2 |  |  |  | false |\n| mode | dive_gas_mode | 3 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DiveGas.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DiveGas","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DiveGas.html#t:t/0","title":"ExtFit.Profile.Messages.DiveGas.t/0","type":"type"},{"doc":"Message: `:dive_settings` identified by num=258","ref":"ExtFit.Profile.Messages.DiveSettings.html","title":"ExtFit.Profile.Messages.DiveSettings","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| name | string | 0 |  |  |  | false |\n| model | tissue_model_type | 1 |  |  |  | false |\n| gf_low | uint8 | 2 |  |  | percent | false |\n| gf_high | uint8 | 3 |  |  | percent | false |\n| water_type | water_type | 4 |  |  |  | false |\n| water_density | float32 | 5 |  |  | kg/m^3 | false |\n| po2_warn | uint8 | 6 | 100 |  | percent | false |\n| po2_critical | uint8 | 7 | 100 |  | percent | false |\n| po2_deco | uint8 | 8 | 100 |  | percent | false |\n| safety_stop_enabled | bool | 9 |  |  |  | false |\n| bottom_depth | float32 | 10 |  |  |  | false |\n| bottom_time | uint32 | 11 |  |  |  | false |\n| apnea_countdown_enabled | bool | 12 |  |  |  | false |\n| apnea_countdown_time | uint32 | 13 |  |  |  | false |\n| backlight_mode | dive_backlight_mode | 14 |  |  |  | false |\n| backlight_brightness | uint8 | 15 |  |  |  | false |\n| backlight_timeout | backlight_timeout | 16 |  |  |  | false |\n| repeat_dive_interval | uint16 | 17 | 1 |  | s | false |\n| safety_stop_time | uint16 | 18 | 1 |  | s | false |\n| heart_rate_source_type | source_type | 19 |  |  |  | false |\n| heart_rate_source | uint8 | 20 |  |  |  | false |\n| travel_gas | message_index | 21 |  |  |  | false |\n| ccr_low_setpoint_switch_mode | ccr_setpoint_switch_mode | 22 |  |  |  | false |\n| ccr_low_setpoint | uint8 | 23 | 100 |  | percent | false |\n| ccr_low_setpoint_depth | uint32 | 24 | 1000 |  | m | false |\n| ccr_high_setpoint_switch_mode | ccr_setpoint_switch_mode | 25 |  |  |  | false |\n| ccr_high_setpoint | uint8 | 26 | 100 |  | percent | false |\n| ccr_high_setpoint_depth | uint32 | 27 | 1000 |  | m | false |\n| gas_consumption_display | gas_consumption_rate_type | 29 |  |  |  | false |\n| up_key_enabled | bool | 30 |  |  |  | false |\n| dive_sounds | tone | 35 |  |  |  | false |\n| last_stop_multiple | uint8 | 36 | 10 |  |  | false |\n| no_fly_time_mode | no_fly_time_mode | 37 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.DiveSettings.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DiveSettings","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DiveSettings.html#t:t/0","title":"ExtFit.Profile.Messages.DiveSettings.t/0","type":"type"},{"doc":"Message: `:dive_summary` identified by num=268","ref":"ExtFit.Profile.Messages.DiveSummary.html","title":"ExtFit.Profile.Messages.DiveSummary","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| reference_mesg | mesg_num | 0 |  |  |  | false |\n| reference_index | message_index | 1 |  |  |  | false |\n| avg_depth | uint32 | 2 | 1000 |  | m | false |\n| max_depth | uint32 | 3 | 1000 |  | m | false |\n| surface_interval | uint32 | 4 | 1 |  | s | false |\n| start_cns | uint8 | 5 | 1 |  | percent | false |\n| end_cns | uint8 | 6 | 1 |  | percent | false |\n| start_n2 | uint16 | 7 | 1 |  | percent | false |\n| end_n2 | uint16 | 8 | 1 |  | percent | false |\n| o2_toxicity | uint16 | 9 |  |  | OTUs | false |\n| dive_number | uint32 | 10 |  |  |  | false |\n| bottom_time | uint32 | 11 | 1000 |  | s | false |\n| avg_pressure_sac | uint16 | 12 | 100 |  | bar/min | false |\n| avg_volume_sac | uint16 | 13 | 100 |  | L/min | false |\n| avg_rmv | uint16 | 14 | 100 |  | L/min | false |\n| descent_time | uint32 | 15 | 1000 |  | s | false |\n| ascent_time | uint32 | 16 | 1000 |  | s | false |\n| avg_ascent_rate | sint32 | 17 | 1000 |  | m/s | false |\n| avg_descent_rate | uint32 | 22 | 1000 |  | m/s | false |\n| max_ascent_rate | uint32 | 23 | 1000 |  | m/s | false |\n| max_descent_rate | uint32 | 24 | 1000 |  | m/s | false |\n| hang_time | uint32 | 25 | 1000 |  | s | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.DiveSummary.html#module-fields","title":"Fields - ExtFit.Profile.Messages.DiveSummary","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.DiveSummary.html#t:t/0","title":"ExtFit.Profile.Messages.DiveSummary.t/0","type":"type"},{"doc":"Message: `:event` identified by num=21","ref":"ExtFit.Profile.Messages.Event.html","title":"ExtFit.Profile.Messages.Event","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| event | event | 0 |  |  |  | false |\n| event_type | event_type | 1 |  |  |  | false |\n| data16 | uint16 | 2 |  |  |  | false |\n| data | uint32 | 3 |  |  |  | false |\n| event_group | uint8 | 4 |  |  |  | false |\n| score | uint16 | 7 |  |  |  | false |\n| opponent_score | uint16 | 8 |  |  |  | false |\n| front_gear_num | uint8z | 9 |  |  |  | false |\n| front_gear | uint8z | 10 |  |  |  | false |\n| rear_gear_num | uint8z | 11 |  |  |  | false |\n| rear_gear | uint8z | 12 |  |  |  | false |\n| device_index | device_index | 13 |  |  |  | false |\n| activity_type | activity_type | 14 |  |  |  | false |\n| start_timestamp | date_time | 15 |  |  | s | false |\n| radar_threat_level_max | radar_threat_level_type | 21 |  |  |  | false |\n| radar_threat_count | uint8 | 22 |  |  |  | false |\n| radar_threat_avg_approach_speed | uint8 | 23 | 10 |  | m/s | false |\n| radar_threat_max_approach_speed | uint8 | 24 | 10 |  | m/s | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.Event.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Event","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Event.html#t:t/0","title":"ExtFit.Profile.Messages.Event.t/0","type":"type"},{"doc":"Message: `:exd_data_concept_configuration` identified by num=202","ref":"ExtFit.Profile.Messages.ExdDataConceptConfiguration.html","title":"ExtFit.Profile.Messages.ExdDataConceptConfiguration","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| screen_index | uint8 | 0 |  |  |  | false |\n| concept_field | byte | 1 |  |  |  | false |\n| field_id | uint8 | 2 |  |  |  | false |\n| concept_index | uint8 | 3 |  |  |  | false |\n| data_page | uint8 | 4 |  |  |  | false |\n| concept_key | uint8 | 5 |  |  |  | false |\n| scaling | uint8 | 6 |  |  |  | false |\n| data_units | exd_data_units | 8 |  |  |  | false |\n| qualifier | exd_qualifiers | 9 |  |  |  | false |\n| descriptor | exd_descriptors | 10 |  |  |  | false |\n| is_signed | bool | 11 |  |  |  | false |","ref":"ExtFit.Profile.Messages.ExdDataConceptConfiguration.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ExdDataConceptConfiguration","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ExdDataConceptConfiguration.html#t:t/0","title":"ExtFit.Profile.Messages.ExdDataConceptConfiguration.t/0","type":"type"},{"doc":"Message: `:exd_data_field_configuration` identified by num=201","ref":"ExtFit.Profile.Messages.ExdDataFieldConfiguration.html","title":"ExtFit.Profile.Messages.ExdDataFieldConfiguration","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| screen_index | uint8 | 0 |  |  |  | false |\n| concept_field | byte | 1 |  |  |  | false |\n| field_id | uint8 | 2 |  |  |  | false |\n| concept_count | uint8 | 3 |  |  |  | false |\n| display_type | exd_display_type | 4 |  |  |  | false |\n| title | string | 5 |  |  |  | 32 |","ref":"ExtFit.Profile.Messages.ExdDataFieldConfiguration.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ExdDataFieldConfiguration","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ExdDataFieldConfiguration.html#t:t/0","title":"ExtFit.Profile.Messages.ExdDataFieldConfiguration.t/0","type":"type"},{"doc":"Message: `:exd_screen_configuration` identified by num=200","ref":"ExtFit.Profile.Messages.ExdScreenConfiguration.html","title":"ExtFit.Profile.Messages.ExdScreenConfiguration","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| screen_index | uint8 | 0 |  |  |  | false |\n| field_count | uint8 | 1 |  |  |  | false |\n| layout | exd_layout | 2 |  |  |  | false |\n| screen_enabled | bool | 3 |  |  |  | false |","ref":"ExtFit.Profile.Messages.ExdScreenConfiguration.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ExdScreenConfiguration","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ExdScreenConfiguration.html#t:t/0","title":"ExtFit.Profile.Messages.ExdScreenConfiguration.t/0","type":"type"},{"doc":"Message: `:exercise_title` identified by num=264","ref":"ExtFit.Profile.Messages.ExerciseTitle.html","title":"ExtFit.Profile.Messages.ExerciseTitle","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| exercise_category | exercise_category | 0 |  |  |  | false |\n| exercise_name | uint16 | 1 |  |  |  | false |\n| wkt_step_name | string | 2 |  |  |  | true |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.ExerciseTitle.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ExerciseTitle","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ExerciseTitle.html#t:t/0","title":"ExtFit.Profile.Messages.ExerciseTitle.t/0","type":"type"},{"doc":"Message: `:field_capabilities` identified by num=39","ref":"ExtFit.Profile.Messages.FieldCapabilities.html","title":"ExtFit.Profile.Messages.FieldCapabilities","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| file | file | 0 |  |  |  | false |\n| mesg_num | mesg_num | 1 |  |  |  | false |\n| field_num | uint8 | 2 |  |  |  | false |\n| count | uint16 | 3 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.FieldCapabilities.html#module-fields","title":"Fields - ExtFit.Profile.Messages.FieldCapabilities","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.FieldCapabilities.html#t:t/0","title":"ExtFit.Profile.Messages.FieldCapabilities.t/0","type":"type"},{"doc":"Message: `:field_description` identified by num=206","ref":"ExtFit.Profile.Messages.FieldDescription.html","title":"ExtFit.Profile.Messages.FieldDescription","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| developer_data_index | uint8 | 0 |  |  |  | false |\n| field_definition_number | uint8 | 1 |  |  |  | false |\n| fit_base_type_id | fit_base_type | 2 |  |  |  | false |\n| field_name | string | 3 |  |  |  | true |\n| array | uint8 | 4 |  |  |  | false |\n| components | string | 5 |  |  |  | false |\n| scale | uint8 | 6 |  |  |  | false |\n| offset | sint8 | 7 |  |  |  | false |\n| units | string | 8 |  |  |  | true |\n| bits | string | 9 |  |  |  | false |\n| accumulate | string | 10 |  |  |  | false |\n| fit_base_unit_id | fit_base_unit | 13 |  |  |  | false |\n| native_mesg_num | mesg_num | 14 |  |  |  | false |\n| native_field_num | uint8 | 15 |  |  |  | false |","ref":"ExtFit.Profile.Messages.FieldDescription.html#module-fields","title":"Fields - ExtFit.Profile.Messages.FieldDescription","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.FieldDescription.html#t:t/0","title":"ExtFit.Profile.Messages.FieldDescription.t/0","type":"type"},{"doc":"Message: `:file_capabilities` identified by num=37","ref":"ExtFit.Profile.Messages.FileCapabilities.html","title":"ExtFit.Profile.Messages.FileCapabilities","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| type | file | 0 |  |  |  | false |\n| flags | file_flags | 1 |  |  |  | false |\n| directory | string | 2 |  |  |  | false |\n| max_count | uint16 | 3 |  |  |  | false |\n| max_size | uint32 | 4 |  |  | bytes | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.FileCapabilities.html#module-fields","title":"Fields - ExtFit.Profile.Messages.FileCapabilities","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.FileCapabilities.html#t:t/0","title":"ExtFit.Profile.Messages.FileCapabilities.t/0","type":"type"},{"doc":"Message: `:file_creator` identified by num=49","ref":"ExtFit.Profile.Messages.FileCreator.html","title":"ExtFit.Profile.Messages.FileCreator","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| software_version | uint16 | 0 |  |  |  | false |\n| hardware_version | uint8 | 1 |  |  |  | false |","ref":"ExtFit.Profile.Messages.FileCreator.html#module-fields","title":"Fields - ExtFit.Profile.Messages.FileCreator","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.FileCreator.html#t:t/0","title":"ExtFit.Profile.Messages.FileCreator.t/0","type":"type"},{"doc":"Message: `:file_id` identified by num=0","ref":"ExtFit.Profile.Messages.FileId.html","title":"ExtFit.Profile.Messages.FileId","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| type | file | 0 |  |  |  | false |\n| manufacturer | manufacturer | 1 |  |  |  | false |\n| product | uint16 | 2 |  |  |  | false |\n| serial_number | uint32z | 3 |  |  |  | false |\n| time_created | date_time | 4 |  |  |  | false |\n| number | uint16 | 5 |  |  |  | false |\n| product_name | string | 8 |  |  |  | false |","ref":"ExtFit.Profile.Messages.FileId.html#module-fields","title":"Fields - ExtFit.Profile.Messages.FileId","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.FileId.html#t:t/0","title":"ExtFit.Profile.Messages.FileId.t/0","type":"type"},{"doc":"Message: `:goal` identified by num=15","ref":"ExtFit.Profile.Messages.Goal.html","title":"ExtFit.Profile.Messages.Goal","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sport | sport | 0 |  |  |  | false |\n| sub_sport | sub_sport | 1 |  |  |  | false |\n| start_date | date_time | 2 |  |  |  | false |\n| end_date | date_time | 3 |  |  |  | false |\n| type | goal | 4 |  |  |  | false |\n| value | uint32 | 5 |  |  |  | false |\n| repeat | bool | 6 |  |  |  | false |\n| target_value | uint32 | 7 |  |  |  | false |\n| recurrence | goal_recurrence | 8 |  |  |  | false |\n| recurrence_value | uint16 | 9 |  |  |  | false |\n| enabled | bool | 10 |  |  |  | false |\n| source | goal_source | 11 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Goal.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Goal","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Goal.html#t:t/0","title":"ExtFit.Profile.Messages.Goal.t/0","type":"type"},{"doc":"Message: `:gps_metadata` identified by num=160","ref":"ExtFit.Profile.Messages.GpsMetadata.html","title":"ExtFit.Profile.Messages.GpsMetadata","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| position_lat | sint32 | 1 |  |  | semicircles | false |\n| position_long | sint32 | 2 |  |  | semicircles | false |\n| enhanced_altitude | uint32 | 3 | 5 | 500 | m | false |\n| enhanced_speed | uint32 | 4 | 1000 |  | m/s | false |\n| heading | uint16 | 5 | 100 |  | degrees | false |\n| utc_timestamp | date_time | 6 |  |  | s | false |\n| velocity | sint16 | 7 | 100 |  | m/s | 3 |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.GpsMetadata.html#module-fields","title":"Fields - ExtFit.Profile.Messages.GpsMetadata","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.GpsMetadata.html#t:t/0","title":"ExtFit.Profile.Messages.GpsMetadata.t/0","type":"type"},{"doc":"Message: `:gyroscope_data` identified by num=164","ref":"ExtFit.Profile.Messages.GyroscopeData.html","title":"ExtFit.Profile.Messages.GyroscopeData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| sample_time_offset | uint16 | 1 |  |  | ms | true |\n| gyro_x | uint16 | 2 |  |  | counts | true |\n| gyro_y | uint16 | 3 |  |  | counts | true |\n| gyro_z | uint16 | 4 |  |  | counts | true |\n| calibrated_gyro_x | float32 | 5 |  |  | deg/s | true |\n| calibrated_gyro_y | float32 | 6 |  |  | deg/s | true |\n| calibrated_gyro_z | float32 | 7 |  |  | deg/s | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.GyroscopeData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.GyroscopeData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.GyroscopeData.html#t:t/0","title":"ExtFit.Profile.Messages.GyroscopeData.t/0","type":"type"},{"doc":"Message: `:hr` identified by num=132","ref":"ExtFit.Profile.Messages.Hr.html","title":"ExtFit.Profile.Messages.Hr","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| fractional_timestamp | uint16 | 0 | 32768 |  | s | false |\n| time256 | uint8 | 1 | 256 |  | s | false |\n| filtered_bpm | uint8 | 6 |  |  | bpm | true |\n| event_timestamp | uint32 | 9 | 1024 |  | s | true |\n| event_timestamp_12 | byte | 10 |  |  |  | true |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Hr.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Hr","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Hr.html#t:t/0","title":"ExtFit.Profile.Messages.Hr.t/0","type":"type"},{"doc":"Message: `:hr_zone` identified by num=8","ref":"ExtFit.Profile.Messages.HrZone.html","title":"ExtFit.Profile.Messages.HrZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| high_bpm | uint8 | 1 |  |  | bpm | false |\n| name | string | 2 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.HrZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.HrZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.HrZone.html#t:t/0","title":"ExtFit.Profile.Messages.HrZone.t/0","type":"type"},{"doc":"Message: `:hrm_profile` identified by num=4","ref":"ExtFit.Profile.Messages.HrmProfile.html","title":"ExtFit.Profile.Messages.HrmProfile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| enabled | bool | 0 |  |  |  | false |\n| hrm_ant_id | uint16z | 1 |  |  |  | false |\n| log_hrv | bool | 2 |  |  |  | false |\n| hrm_ant_id_trans_type | uint8z | 3 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.HrmProfile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.HrmProfile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.HrmProfile.html#t:t/0","title":"ExtFit.Profile.Messages.HrmProfile.t/0","type":"type"},{"doc":"Message: `:hrv` identified by num=78","ref":"ExtFit.Profile.Messages.Hrv.html","title":"ExtFit.Profile.Messages.Hrv","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| time | uint16 | 0 | 1000 |  | s | true |","ref":"ExtFit.Profile.Messages.Hrv.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Hrv","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Hrv.html#t:t/0","title":"ExtFit.Profile.Messages.Hrv.t/0","type":"type"},{"doc":"Message: `:hrv_status_summary` identified by num=370","ref":"ExtFit.Profile.Messages.HrvStatusSummary.html","title":"ExtFit.Profile.Messages.HrvStatusSummary","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| weekly_average | uint16 | 0 | 128 |  | ms | false |\n| last_night_average | uint16 | 1 | 128 |  | ms | false |\n| last_night_5_min_high | uint16 | 2 | 128 |  | ms | false |\n| baseline_low_upper | uint16 | 3 | 128 |  | ms | false |\n| baseline_balanced_lower | uint16 | 4 | 128 |  | ms | false |\n| baseline_balanced_upper | uint16 | 5 | 128 |  | ms | false |\n| status | hrv_status | 6 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.HrvStatusSummary.html#module-fields","title":"Fields - ExtFit.Profile.Messages.HrvStatusSummary","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.HrvStatusSummary.html#t:t/0","title":"ExtFit.Profile.Messages.HrvStatusSummary.t/0","type":"type"},{"doc":"Message: `:hrv_value` identified by num=371","ref":"ExtFit.Profile.Messages.HrvValue.html","title":"ExtFit.Profile.Messages.HrvValue","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| value | uint16 | 0 | 128 |  | ms | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.HrvValue.html#module-fields","title":"Fields - ExtFit.Profile.Messages.HrvValue","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.HrvValue.html#t:t/0","title":"ExtFit.Profile.Messages.HrvValue.t/0","type":"type"},{"doc":"Message: `:jump` identified by num=285","ref":"ExtFit.Profile.Messages.Jump.html","title":"ExtFit.Profile.Messages.Jump","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| distance | float32 | 0 |  |  | m | false |\n| height | float32 | 1 |  |  | m | false |\n| rotations | uint8 | 2 |  |  |  | false |\n| hang_time | float32 | 3 |  |  | s | false |\n| score | float32 | 4 |  |  |  | false |\n| position_lat | sint32 | 5 |  |  | semicircles | false |\n| position_long | sint32 | 6 |  |  | semicircles | false |\n| speed | uint16 | 7 | 1000 |  | m/s | false |\n| enhanced_speed | uint32 | 8 | 1000 |  | m/s | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.Jump.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Jump","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Jump.html#t:t/0","title":"ExtFit.Profile.Messages.Jump.t/0","type":"type"},{"doc":"Message: `:lap` identified by num=19","ref":"ExtFit.Profile.Messages.Lap.html","title":"ExtFit.Profile.Messages.Lap","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| event | event | 0 |  |  |  | false |\n| event_type | event_type | 1 |  |  |  | false |\n| start_time | date_time | 2 |  |  |  | false |\n| start_position_lat | sint32 | 3 |  |  | semicircles | false |\n| start_position_long | sint32 | 4 |  |  | semicircles | false |\n| end_position_lat | sint32 | 5 |  |  | semicircles | false |\n| end_position_long | sint32 | 6 |  |  | semicircles | false |\n| total_elapsed_time | uint32 | 7 | 1000 |  | s | false |\n| total_timer_time | uint32 | 8 | 1000 |  | s | false |\n| total_distance | uint32 | 9 | 100 |  | m | false |\n| total_cycles | uint32 | 10 |  |  | cycles | false |\n| total_calories | uint16 | 11 |  |  | kcal | false |\n| total_fat_calories | uint16 | 12 |  |  | kcal | false |\n| avg_speed | uint16 | 13 | 1000 |  | m/s | false |\n| max_speed | uint16 | 14 | 1000 |  | m/s | false |\n| avg_heart_rate | uint8 | 15 |  |  | bpm | false |\n| max_heart_rate | uint8 | 16 |  |  | bpm | false |\n| avg_cadence | uint8 | 17 |  |  | rpm | false |\n| max_cadence | uint8 | 18 |  |  | rpm | false |\n| avg_power | uint16 | 19 |  |  | watts | false |\n| max_power | uint16 | 20 |  |  | watts | false |\n| total_ascent | uint16 | 21 |  |  | m | false |\n| total_descent | uint16 | 22 |  |  | m | false |\n| intensity | intensity | 23 |  |  |  | false |\n| lap_trigger | lap_trigger | 24 |  |  |  | false |\n| sport | sport | 25 |  |  |  | false |\n| event_group | uint8 | 26 |  |  |  | false |\n| num_lengths | uint16 | 32 |  |  | lengths | false |\n| normalized_power | uint16 | 33 |  |  | watts | false |\n| left_right_balance | left_right_balance_100 | 34 |  |  |  | false |\n| first_length_index | uint16 | 35 |  |  |  | false |\n| avg_stroke_distance | uint16 | 37 | 100 |  | m | false |\n| swim_stroke | swim_stroke | 38 |  |  |  | false |\n| sub_sport | sub_sport | 39 |  |  |  | false |\n| num_active_lengths | uint16 | 40 |  |  | lengths | false |\n| total_work | uint32 | 41 |  |  | J | false |\n| avg_altitude | uint16 | 42 | 5 | 500 | m | false |\n| max_altitude | uint16 | 43 | 5 | 500 | m | false |\n| gps_accuracy | uint8 | 44 |  |  | m | false |\n| avg_grade | sint16 | 45 | 100 |  | % | false |\n| avg_pos_grade | sint16 | 46 | 100 |  | % | false |\n| avg_neg_grade | sint16 | 47 | 100 |  | % | false |\n| max_pos_grade | sint16 | 48 | 100 |  | % | false |\n| max_neg_grade | sint16 | 49 | 100 |  | % | false |\n| avg_temperature | sint8 | 50 |  |  | C | false |\n| max_temperature | sint8 | 51 |  |  | C | false |\n| total_moving_time | uint32 | 52 | 1000 |  | s | false |\n| avg_pos_vertical_speed | sint16 | 53 | 1000 |  | m/s | false |\n| avg_neg_vertical_speed | sint16 | 54 | 1000 |  | m/s | false |\n| max_pos_vertical_speed | sint16 | 55 | 1000 |  | m/s | false |\n| max_neg_vertical_speed | sint16 | 56 | 1000 |  | m/s | false |\n| time_in_hr_zone | uint32 | 57 | 1000 |  | s | true |\n| time_in_speed_zone | uint32 | 58 | 1000 |  | s | true |\n| time_in_cadence_zone | uint32 | 59 | 1000 |  | s | true |\n| time_in_power_zone | uint32 | 60 | 1000 |  | s | true |\n| repetition_num | uint16 | 61 |  |  |  | false |\n| min_altitude | uint16 | 62 | 5 | 500 | m | false |\n| min_heart_rate | uint8 | 63 |  |  | bpm | false |\n| wkt_step_index | message_index | 71 |  |  |  | false |\n| opponent_score | uint16 | 74 |  |  |  | false |\n| stroke_count | uint16 | 75 |  |  | counts | true |\n| zone_count | uint16 | 76 |  |  | counts | true |\n| avg_vertical_oscillation | uint16 | 77 | 10 |  | mm | false |\n| avg_stance_time_percent | uint16 | 78 | 100 |  | percent | false |\n| avg_stance_time | uint16 | 79 | 10 |  | ms | false |\n| avg_fractional_cadence | uint8 | 80 | 128 |  | rpm | false |\n| max_fractional_cadence | uint8 | 81 | 128 |  | rpm | false |\n| total_fractional_cycles | uint8 | 82 | 128 |  | cycles | false |\n| player_score | uint16 | 83 |  |  |  | false |\n| avg_total_hemoglobin_conc | uint16 | 84 | 100 |  | g/dL | true |\n| min_total_hemoglobin_conc | uint16 | 85 | 100 |  | g/dL | true |\n| max_total_hemoglobin_conc | uint16 | 86 | 100 |  | g/dL | true |\n| avg_saturated_hemoglobin_percent | uint16 | 87 | 10 |  | % | true |\n| min_saturated_hemoglobin_percent | uint16 | 88 | 10 |  | % | true |\n| max_saturated_hemoglobin_percent | uint16 | 89 | 10 |  | % | true |\n| avg_left_torque_effectiveness | uint8 | 91 | 2 |  | percent | false |\n| avg_right_torque_effectiveness | uint8 | 92 | 2 |  | percent | false |\n| avg_left_pedal_smoothness | uint8 | 93 | 2 |  | percent | false |\n| avg_right_pedal_smoothness | uint8 | 94 | 2 |  | percent | false |\n| avg_combined_pedal_smoothness | uint8 | 95 | 2 |  | percent | false |\n| time_standing | uint32 | 98 | 1000 |  | s | false |\n| stand_count | uint16 | 99 |  |  |  | false |\n| avg_left_pco | sint8 | 100 |  |  | mm | false |\n| avg_right_pco | sint8 | 101 |  |  | mm | false |\n| avg_left_power_phase | uint8 | 102 | 0.7111111 |  | degrees | true |\n| avg_left_power_phase_peak | uint8 | 103 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase | uint8 | 104 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase_peak | uint8 | 105 | 0.7111111 |  | degrees | true |\n| avg_power_position | uint16 | 106 |  |  | watts | true |\n| max_power_position | uint16 | 107 |  |  | watts | true |\n| avg_cadence_position | uint8 | 108 |  |  | rpm | true |\n| max_cadence_position | uint8 | 109 |  |  | rpm | true |\n| enhanced_avg_speed | uint32 | 110 | 1000 |  | m/s | false |\n| enhanced_max_speed | uint32 | 111 | 1000 |  | m/s | false |\n| enhanced_avg_altitude | uint32 | 112 | 5 | 500 | m | false |\n| enhanced_min_altitude | uint32 | 113 | 5 | 500 | m | false |\n| enhanced_max_altitude | uint32 | 114 | 5 | 500 | m | false |\n| avg_lev_motor_power | uint16 | 115 |  |  | watts | false |\n| max_lev_motor_power | uint16 | 116 |  |  | watts | false |\n| lev_battery_consumption | uint8 | 117 | 2 |  | percent | false |\n| avg_vertical_ratio | uint16 | 118 | 100 |  | percent | false |\n| avg_stance_time_balance | uint16 | 119 | 100 |  | percent | false |\n| avg_step_length | uint16 | 120 | 10 |  | mm | false |\n| avg_vam | uint16 | 121 | 1000 |  | m/s | false |\n| avg_depth | uint32 | 122 | 1000 |  | m | false |\n| max_depth | uint32 | 123 | 1000 |  | m | false |\n| min_temperature | sint8 | 124 |  |  | C | false |\n| enhanced_avg_respiration_rate | uint16 | 136 | 100 |  | Breaths/min | false |\n| enhanced_max_respiration_rate | uint16 | 137 | 100 |  | Breaths/min | false |\n| avg_respiration_rate | uint8 | 147 |  |  |  | false |\n| max_respiration_rate | uint8 | 148 |  |  |  | false |\n| total_grit | float32 | 149 |  |  | kGrit | false |\n| total_flow | float32 | 150 |  |  | Flow | false |\n| jump_count | uint16 | 151 |  |  |  | false |\n| avg_grit | float32 | 153 |  |  | kGrit | false |\n| avg_flow | float32 | 154 |  |  | Flow | false |\n| total_fractional_ascent | uint8 | 156 | 100 |  | m | false |\n| total_fractional_descent | uint8 | 157 | 100 |  | m | false |\n| avg_core_temperature | uint16 | 158 | 100 |  | C | false |\n| min_core_temperature | uint16 | 159 | 100 |  | C | false |\n| max_core_temperature | uint16 | 160 | 100 |  | C | false |\n| timestamp | date_time | 253 |  |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Lap.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Lap","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Lap.html#t:t/0","title":"ExtFit.Profile.Messages.Lap.t/0","type":"type"},{"doc":"Message: `:length` identified by num=101","ref":"ExtFit.Profile.Messages.Length.html","title":"ExtFit.Profile.Messages.Length","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| event | event | 0 |  |  |  | false |\n| event_type | event_type | 1 |  |  |  | false |\n| start_time | date_time | 2 |  |  |  | false |\n| total_elapsed_time | uint32 | 3 | 1000 |  | s | false |\n| total_timer_time | uint32 | 4 | 1000 |  | s | false |\n| total_strokes | uint16 | 5 |  |  | strokes | false |\n| avg_speed | uint16 | 6 | 1000 |  | m/s | false |\n| swim_stroke | swim_stroke | 7 |  |  | swim_stroke | false |\n| avg_swimming_cadence | uint8 | 9 |  |  | strokes/min | false |\n| event_group | uint8 | 10 |  |  |  | false |\n| total_calories | uint16 | 11 |  |  | kcal | false |\n| length_type | length_type | 12 |  |  |  | false |\n| player_score | uint16 | 18 |  |  |  | false |\n| opponent_score | uint16 | 19 |  |  |  | false |\n| stroke_count | uint16 | 20 |  |  | counts | true |\n| zone_count | uint16 | 21 |  |  | counts | true |\n| enhanced_avg_respiration_rate | uint16 | 22 | 100 |  | Breaths/min | false |\n| enhanced_max_respiration_rate | uint16 | 23 | 100 |  | Breaths/min | false |\n| avg_respiration_rate | uint8 | 24 |  |  |  | false |\n| max_respiration_rate | uint8 | 25 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Length.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Length","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Length.html#t:t/0","title":"ExtFit.Profile.Messages.Length.t/0","type":"type"},{"doc":"Message: `:magnetometer_data` identified by num=208","ref":"ExtFit.Profile.Messages.MagnetometerData.html","title":"ExtFit.Profile.Messages.MagnetometerData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| sample_time_offset | uint16 | 1 |  |  | ms | true |\n| mag_x | uint16 | 2 |  |  | counts | true |\n| mag_y | uint16 | 3 |  |  | counts | true |\n| mag_z | uint16 | 4 |  |  | counts | true |\n| calibrated_mag_x | float32 | 5 |  |  | G | true |\n| calibrated_mag_y | float32 | 6 |  |  | G | true |\n| calibrated_mag_z | float32 | 7 |  |  | G | true |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.MagnetometerData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MagnetometerData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MagnetometerData.html#t:t/0","title":"ExtFit.Profile.Messages.MagnetometerData.t/0","type":"type"},{"doc":"Message: `:max_met_data` identified by num=229","ref":"ExtFit.Profile.Messages.MaxMetData.html","title":"ExtFit.Profile.Messages.MaxMetData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| update_time | date_time | 0 |  |  |  | false |\n| vo2_max | uint16 | 2 | 10 |  | mL/kg/min | false |\n| sport | sport | 5 |  |  |  | false |\n| sub_sport | sub_sport | 6 |  |  |  | false |\n| max_met_category | max_met_category | 8 |  |  |  | false |\n| calibrated_data | bool | 9 |  |  |  | false |\n| hr_source | max_met_heart_rate_source | 12 |  |  |  | false |\n| speed_source | max_met_speed_source | 13 |  |  |  | false |","ref":"ExtFit.Profile.Messages.MaxMetData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MaxMetData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MaxMetData.html#t:t/0","title":"ExtFit.Profile.Messages.MaxMetData.t/0","type":"type"},{"doc":"Message: `:memo_glob` identified by num=145","ref":"ExtFit.Profile.Messages.MemoGlob.html","title":"ExtFit.Profile.Messages.MemoGlob","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| memo | byte | 0 |  |  |  | true |\n| mesg_num | mesg_num | 1 |  |  |  | false |\n| parent_index | message_index | 2 |  |  |  | false |\n| field_num | uint8 | 3 |  |  |  | false |\n| data | uint8z | 4 |  |  |  | true |\n| part_index | uint32 | 250 |  |  |  | false |","ref":"ExtFit.Profile.Messages.MemoGlob.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MemoGlob","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MemoGlob.html#t:t/0","title":"ExtFit.Profile.Messages.MemoGlob.t/0","type":"type"},{"doc":"Message: `:mesg_capabilities` identified by num=38","ref":"ExtFit.Profile.Messages.MesgCapabilities.html","title":"ExtFit.Profile.Messages.MesgCapabilities","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| file | file | 0 |  |  |  | false |\n| mesg_num | mesg_num | 1 |  |  |  | false |\n| count_type | mesg_count | 2 |  |  |  | false |\n| count | uint16 | 3 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.MesgCapabilities.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MesgCapabilities","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MesgCapabilities.html#t:t/0","title":"ExtFit.Profile.Messages.MesgCapabilities.t/0","type":"type"},{"doc":"Message: `:met_zone` identified by num=10","ref":"ExtFit.Profile.Messages.MetZone.html","title":"ExtFit.Profile.Messages.MetZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| high_bpm | uint8 | 1 |  |  |  | false |\n| calories | uint16 | 2 | 10 |  | kcal / min | false |\n| fat_calories | uint8 | 3 | 10 |  | kcal / min | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.MetZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MetZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MetZone.html#t:t/0","title":"ExtFit.Profile.Messages.MetZone.t/0","type":"type"},{"doc":"Message: `:monitoring` identified by num=55","ref":"ExtFit.Profile.Messages.Monitoring.html","title":"ExtFit.Profile.Messages.Monitoring","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| device_index | device_index | 0 |  |  |  | false |\n| calories | uint16 | 1 |  |  | kcal | false |\n| distance | uint32 | 2 | 100 |  | m | false |\n| cycles | uint32 | 3 | 2 |  | cycles | false |\n| active_time | uint32 | 4 | 1000 |  | s | false |\n| activity_type | activity_type | 5 |  |  |  | false |\n| activity_subtype | activity_subtype | 6 |  |  |  | false |\n| activity_level | activity_level | 7 |  |  |  | false |\n| distance_16 | uint16 | 8 |  |  | 100 * m | false |\n| cycles_16 | uint16 | 9 |  |  | 2 * cycles (steps) | false |\n| active_time_16 | uint16 | 10 |  |  | s | false |\n| local_timestamp | local_date_time | 11 |  |  |  | false |\n| temperature | sint16 | 12 | 100 |  | C | false |\n| temperature_min | sint16 | 14 | 100 |  | C | false |\n| temperature_max | sint16 | 15 | 100 |  | C | false |\n| activity_time | uint16 | 16 |  |  | minutes | 8 |\n| active_calories | uint16 | 19 |  |  | kcal | false |\n| current_activity_type_intensity | byte | 24 |  |  |  | false |\n| timestamp_min_8 | uint8 | 25 |  |  | min | false |\n| timestamp_16 | uint16 | 26 |  |  | s | false |\n| heart_rate | uint8 | 27 |  |  | bpm | false |\n| intensity | uint8 | 28 | 10 |  |  | false |\n| duration_min | uint16 | 29 |  |  | min | false |\n| duration | uint32 | 30 |  |  | s | false |\n| ascent | uint32 | 31 | 1000 |  | m | false |\n| descent | uint32 | 32 | 1000 |  | m | false |\n| moderate_activity_minutes | uint16 | 33 |  |  | minutes | false |\n| vigorous_activity_minutes | uint16 | 34 |  |  | minutes | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.Monitoring.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Monitoring","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Monitoring.html#t:t/0","title":"ExtFit.Profile.Messages.Monitoring.t/0","type":"type"},{"doc":"Message: `:monitoring_hr_data` identified by num=211","ref":"ExtFit.Profile.Messages.MonitoringHrData.html","title":"ExtFit.Profile.Messages.MonitoringHrData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| resting_heart_rate | uint8 | 0 |  |  | bpm | false |\n| current_day_resting_heart_rate | uint8 | 1 |  |  | bpm | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.MonitoringHrData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MonitoringHrData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MonitoringHrData.html#t:t/0","title":"ExtFit.Profile.Messages.MonitoringHrData.t/0","type":"type"},{"doc":"Message: `:monitoring_info` identified by num=103","ref":"ExtFit.Profile.Messages.MonitoringInfo.html","title":"ExtFit.Profile.Messages.MonitoringInfo","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| local_timestamp | local_date_time | 0 |  |  | s | false |\n| activity_type | activity_type | 1 |  |  |  | true |\n| cycles_to_distance | uint16 | 3 | 5000 |  | m/cycle | true |\n| cycles_to_calories | uint16 | 4 | 5000 |  | kcal/cycle | true |\n| resting_metabolic_rate | uint16 | 5 |  |  | kcal / day | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.MonitoringInfo.html#module-fields","title":"Fields - ExtFit.Profile.Messages.MonitoringInfo","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.MonitoringInfo.html#t:t/0","title":"ExtFit.Profile.Messages.MonitoringInfo.t/0","type":"type"},{"doc":"Message: `:nmea_sentence` identified by num=177","ref":"ExtFit.Profile.Messages.NmeaSentence.html","title":"ExtFit.Profile.Messages.NmeaSentence","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| sentence | string | 1 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.NmeaSentence.html#module-fields","title":"Fields - ExtFit.Profile.Messages.NmeaSentence","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.NmeaSentence.html#t:t/0","title":"ExtFit.Profile.Messages.NmeaSentence.t/0","type":"type"},{"doc":"Message: `:obdii_data` identified by num=174","ref":"ExtFit.Profile.Messages.ObdiiData.html","title":"ExtFit.Profile.Messages.ObdiiData","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| time_offset | uint16 | 1 |  |  | ms | true |\n| pid | byte | 2 |  |  |  | false |\n| raw_data | byte | 3 |  |  |  | true |\n| pid_data_size | uint8 | 4 |  |  |  | true |\n| system_time | uint32 | 5 |  |  |  | true |\n| start_timestamp | date_time | 6 |  |  |  | false |\n| start_timestamp_ms | uint16 | 7 |  |  | ms | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.ObdiiData.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ObdiiData","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ObdiiData.html#t:t/0","title":"ExtFit.Profile.Messages.ObdiiData.t/0","type":"type"},{"doc":"Message: `:ohr_settings` identified by num=188","ref":"ExtFit.Profile.Messages.OhrSettings.html","title":"ExtFit.Profile.Messages.OhrSettings","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| enabled | switch | 0 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.OhrSettings.html#module-fields","title":"Fields - ExtFit.Profile.Messages.OhrSettings","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.OhrSettings.html#t:t/0","title":"ExtFit.Profile.Messages.OhrSettings.t/0","type":"type"},{"doc":"Message: `:one_d_sensor_calibration` identified by num=210","ref":"ExtFit.Profile.Messages.OneDSensorCalibration.html","title":"ExtFit.Profile.Messages.OneDSensorCalibration","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sensor_type | sensor_type | 0 |  |  |  | false |\n| calibration_factor | uint32 | 1 |  |  |  | false |\n| calibration_divisor | uint32 | 2 |  |  | counts | false |\n| level_shift | uint32 | 3 |  |  |  | false |\n| offset_cal | sint32 | 4 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.OneDSensorCalibration.html#module-fields","title":"Fields - ExtFit.Profile.Messages.OneDSensorCalibration","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.OneDSensorCalibration.html#t:t/0","title":"ExtFit.Profile.Messages.OneDSensorCalibration.t/0","type":"type"},{"doc":"Message: `:power_zone` identified by num=9","ref":"ExtFit.Profile.Messages.PowerZone.html","title":"ExtFit.Profile.Messages.PowerZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| high_value | uint16 | 1 |  |  | watts | false |\n| name | string | 2 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.PowerZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.PowerZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.PowerZone.html#t:t/0","title":"ExtFit.Profile.Messages.PowerZone.t/0","type":"type"},{"doc":"Message: `:record` identified by num=20","ref":"ExtFit.Profile.Messages.Record.html","title":"ExtFit.Profile.Messages.Record","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| position_lat | sint32 | 0 |  |  | semicircles | false |\n| position_long | sint32 | 1 |  |  | semicircles | false |\n| altitude | uint16 | 2 | 5 | 500 | m | false |\n| heart_rate | uint8 | 3 |  |  | bpm | false |\n| cadence | uint8 | 4 |  |  | rpm | false |\n| distance | uint32 | 5 | 100 |  | m | false |\n| speed | uint16 | 6 | 1000 |  | m/s | false |\n| power | uint16 | 7 |  |  | watts | false |\n| compressed_speed_distance | byte | 8 |  |  |  | 3 |\n| grade | sint16 | 9 | 100 |  | % | false |\n| resistance | uint8 | 10 |  |  |  | false |\n| time_from_course | sint32 | 11 | 1000 |  | s | false |\n| cycle_length | uint8 | 12 | 100 |  | m | false |\n| temperature | sint8 | 13 |  |  | C | false |\n| speed_1s | uint8 | 17 | 16 |  | m/s | true |\n| cycles | uint8 | 18 |  |  | cycles | false |\n| total_cycles | uint32 | 19 |  |  | cycles | false |\n| compressed_accumulated_power | uint16 | 28 |  |  | watts | false |\n| accumulated_power | uint32 | 29 |  |  | watts | false |\n| left_right_balance | left_right_balance | 30 |  |  |  | false |\n| gps_accuracy | uint8 | 31 |  |  | m | false |\n| vertical_speed | sint16 | 32 | 1000 |  | m/s | false |\n| calories | uint16 | 33 |  |  | kcal | false |\n| vertical_oscillation | uint16 | 39 | 10 |  | mm | false |\n| stance_time_percent | uint16 | 40 | 100 |  | percent | false |\n| stance_time | uint16 | 41 | 10 |  | ms | false |\n| activity_type | activity_type | 42 |  |  |  | false |\n| left_torque_effectiveness | uint8 | 43 | 2 |  | percent | false |\n| right_torque_effectiveness | uint8 | 44 | 2 |  | percent | false |\n| left_pedal_smoothness | uint8 | 45 | 2 |  | percent | false |\n| right_pedal_smoothness | uint8 | 46 | 2 |  | percent | false |\n| combined_pedal_smoothness | uint8 | 47 | 2 |  | percent | false |\n| time128 | uint8 | 48 | 128 |  | s | false |\n| stroke_type | stroke_type | 49 |  |  |  | false |\n| zone | uint8 | 50 |  |  |  | false |\n| ball_speed | uint16 | 51 | 100 |  | m/s | false |\n| cadence256 | uint16 | 52 | 256 |  | rpm | false |\n| fractional_cadence | uint8 | 53 | 128 |  | rpm | false |\n| total_hemoglobin_conc | uint16 | 54 | 100 |  | g/dL | false |\n| total_hemoglobin_conc_min | uint16 | 55 | 100 |  | g/dL | false |\n| total_hemoglobin_conc_max | uint16 | 56 | 100 |  | g/dL | false |\n| saturated_hemoglobin_percent | uint16 | 57 | 10 |  | % | false |\n| saturated_hemoglobin_percent_min | uint16 | 58 | 10 |  | % | false |\n| saturated_hemoglobin_percent_max | uint16 | 59 | 10 |  | % | false |\n| device_index | device_index | 62 |  |  |  | false |\n| left_pco | sint8 | 67 |  |  | mm | false |\n| right_pco | sint8 | 68 |  |  | mm | false |\n| left_power_phase | uint8 | 69 | 0.7111111 |  | degrees | true |\n| left_power_phase_peak | uint8 | 70 | 0.7111111 |  | degrees | true |\n| right_power_phase | uint8 | 71 | 0.7111111 |  | degrees | true |\n| right_power_phase_peak | uint8 | 72 | 0.7111111 |  | degrees | true |\n| enhanced_speed | uint32 | 73 | 1000 |  | m/s | false |\n| enhanced_altitude | uint32 | 78 | 5 | 500 | m | false |\n| battery_soc | uint8 | 81 | 2 |  | percent | false |\n| motor_power | uint16 | 82 |  |  | watts | false |\n| vertical_ratio | uint16 | 83 | 100 |  | percent | false |\n| stance_time_balance | uint16 | 84 | 100 |  | percent | false |\n| step_length | uint16 | 85 | 10 |  | mm | false |\n| cycle_length16 | uint16 | 87 | 100 |  | m | false |\n| absolute_pressure | uint32 | 91 |  |  | Pa | false |\n| depth | uint32 | 92 | 1000 |  | m | false |\n| next_stop_depth | uint32 | 93 | 1000 |  | m | false |\n| next_stop_time | uint32 | 94 | 1 |  | s | false |\n| time_to_surface | uint32 | 95 | 1 |  | s | false |\n| ndl_time | uint32 | 96 | 1 |  | s | false |\n| cns_load | uint8 | 97 |  |  | percent | false |\n| n2_load | uint16 | 98 | 1 |  | percent | false |\n| respiration_rate | uint8 | 99 | 1 |  | s | false |\n| enhanced_respiration_rate | uint16 | 108 | 100 |  | Breaths/min | false |\n| grit | float32 | 114 |  |  |  | false |\n| flow | float32 | 115 |  |  |  | false |\n| current_stress | uint16 | 116 | 100 |  |  | false |\n| ebike_travel_range | uint16 | 117 |  |  | km | false |\n| ebike_battery_level | uint8 | 118 |  |  | percent | false |\n| ebike_assist_mode | uint8 | 119 |  |  | depends on sensor | false |\n| ebike_assist_level_percent | uint8 | 120 |  |  | percent | false |\n| air_time_remaining | uint32 | 123 |  |  | s | false |\n| pressure_sac | uint16 | 124 | 100 |  | bar/min | false |\n| volume_sac | uint16 | 125 | 100 |  | L/min | false |\n| rmv | uint16 | 126 | 100 |  | L/min | false |\n| ascent_rate | sint32 | 127 | 1000 |  | m/s | false |\n| po2 | uint8 | 129 | 100 |  | percent | false |\n| core_temperature | uint16 | 139 | 100 |  | C | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.Record.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Record","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Record.html#t:t/0","title":"ExtFit.Profile.Messages.Record.t/0","type":"type"},{"doc":"Message: `:respiration_rate` identified by num=297","ref":"ExtFit.Profile.Messages.RespirationRate.html","title":"ExtFit.Profile.Messages.RespirationRate","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| respiration_rate | sint16 | 0 | 100 |  | breaths/min | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.RespirationRate.html#module-fields","title":"Fields - ExtFit.Profile.Messages.RespirationRate","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.RespirationRate.html#t:t/0","title":"ExtFit.Profile.Messages.RespirationRate.t/0","type":"type"},{"doc":"Message: `:schedule` identified by num=28","ref":"ExtFit.Profile.Messages.Schedule.html","title":"ExtFit.Profile.Messages.Schedule","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| manufacturer | manufacturer | 0 |  |  |  | false |\n| product | uint16 | 1 |  |  |  | false |\n| serial_number | uint32z | 2 |  |  |  | false |\n| time_created | date_time | 3 |  |  |  | false |\n| completed | bool | 4 |  |  |  | false |\n| type | schedule | 5 |  |  |  | false |\n| scheduled_time | local_date_time | 6 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Schedule.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Schedule","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Schedule.html#t:t/0","title":"ExtFit.Profile.Messages.Schedule.t/0","type":"type"},{"doc":"Message: `:sdm_profile` identified by num=5","ref":"ExtFit.Profile.Messages.SdmProfile.html","title":"ExtFit.Profile.Messages.SdmProfile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| enabled | bool | 0 |  |  |  | false |\n| sdm_ant_id | uint16z | 1 |  |  |  | false |\n| sdm_cal_factor | uint16 | 2 | 10 |  | % | false |\n| odometer | uint32 | 3 | 100 |  | m | false |\n| speed_source | bool | 4 |  |  |  | false |\n| sdm_ant_id_trans_type | uint8z | 5 |  |  |  | false |\n| odometer_rollover | uint8 | 7 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SdmProfile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SdmProfile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SdmProfile.html#t:t/0","title":"ExtFit.Profile.Messages.SdmProfile.t/0","type":"type"},{"doc":"Message: `:segment_file` identified by num=151","ref":"ExtFit.Profile.Messages.SegmentFile.html","title":"ExtFit.Profile.Messages.SegmentFile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| file_uuid | string | 1 |  |  |  | false |\n| enabled | bool | 3 |  |  |  | false |\n| user_profile_primary_key | uint32 | 4 |  |  |  | false |\n| leader_type | segment_leaderboard_type | 7 |  |  |  | true |\n| leader_group_primary_key | uint32 | 8 |  |  |  | true |\n| leader_activity_id | uint32 | 9 |  |  |  | true |\n| leader_activity_id_string | string | 10 |  |  |  | true |\n| default_race_leader | uint8 | 11 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SegmentFile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SegmentFile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SegmentFile.html#t:t/0","title":"ExtFit.Profile.Messages.SegmentFile.t/0","type":"type"},{"doc":"Message: `:segment_id` identified by num=148","ref":"ExtFit.Profile.Messages.SegmentId.html","title":"ExtFit.Profile.Messages.SegmentId","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| name | string | 0 |  |  |  | false |\n| uuid | string | 1 |  |  |  | false |\n| sport | sport | 2 |  |  |  | false |\n| enabled | bool | 3 |  |  |  | false |\n| user_profile_primary_key | uint32 | 4 |  |  |  | false |\n| device_id | uint32 | 5 |  |  |  | false |\n| default_race_leader | uint8 | 6 |  |  |  | false |\n| delete_status | segment_delete_status | 7 |  |  |  | false |\n| selection_type | segment_selection_type | 8 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SegmentId.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SegmentId","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SegmentId.html#t:t/0","title":"ExtFit.Profile.Messages.SegmentId.t/0","type":"type"},{"doc":"Message: `:segment_lap` identified by num=142","ref":"ExtFit.Profile.Messages.SegmentLap.html","title":"ExtFit.Profile.Messages.SegmentLap","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| event | event | 0 |  |  |  | false |\n| event_type | event_type | 1 |  |  |  | false |\n| start_time | date_time | 2 |  |  |  | false |\n| start_position_lat | sint32 | 3 |  |  | semicircles | false |\n| start_position_long | sint32 | 4 |  |  | semicircles | false |\n| end_position_lat | sint32 | 5 |  |  | semicircles | false |\n| end_position_long | sint32 | 6 |  |  | semicircles | false |\n| total_elapsed_time | uint32 | 7 | 1000 |  | s | false |\n| total_timer_time | uint32 | 8 | 1000 |  | s | false |\n| total_distance | uint32 | 9 | 100 |  | m | false |\n| total_cycles | uint32 | 10 |  |  | cycles | false |\n| total_calories | uint16 | 11 |  |  | kcal | false |\n| total_fat_calories | uint16 | 12 |  |  | kcal | false |\n| avg_speed | uint16 | 13 | 1000 |  | m/s | false |\n| max_speed | uint16 | 14 | 1000 |  | m/s | false |\n| avg_heart_rate | uint8 | 15 |  |  | bpm | false |\n| max_heart_rate | uint8 | 16 |  |  | bpm | false |\n| avg_cadence | uint8 | 17 |  |  | rpm | false |\n| max_cadence | uint8 | 18 |  |  | rpm | false |\n| avg_power | uint16 | 19 |  |  | watts | false |\n| max_power | uint16 | 20 |  |  | watts | false |\n| total_ascent | uint16 | 21 |  |  | m | false |\n| total_descent | uint16 | 22 |  |  | m | false |\n| sport | sport | 23 |  |  |  | false |\n| event_group | uint8 | 24 |  |  |  | false |\n| nec_lat | sint32 | 25 |  |  | semicircles | false |\n| nec_long | sint32 | 26 |  |  | semicircles | false |\n| swc_lat | sint32 | 27 |  |  | semicircles | false |\n| swc_long | sint32 | 28 |  |  | semicircles | false |\n| name | string | 29 |  |  |  | false |\n| normalized_power | uint16 | 30 |  |  | watts | false |\n| left_right_balance | left_right_balance_100 | 31 |  |  |  | false |\n| sub_sport | sub_sport | 32 |  |  |  | false |\n| total_work | uint32 | 33 |  |  | J | false |\n| avg_altitude | uint16 | 34 | 5 | 500 | m | false |\n| max_altitude | uint16 | 35 | 5 | 500 | m | false |\n| gps_accuracy | uint8 | 36 |  |  | m | false |\n| avg_grade | sint16 | 37 | 100 |  | % | false |\n| avg_pos_grade | sint16 | 38 | 100 |  | % | false |\n| avg_neg_grade | sint16 | 39 | 100 |  | % | false |\n| max_pos_grade | sint16 | 40 | 100 |  | % | false |\n| max_neg_grade | sint16 | 41 | 100 |  | % | false |\n| avg_temperature | sint8 | 42 |  |  | C | false |\n| max_temperature | sint8 | 43 |  |  | C | false |\n| total_moving_time | uint32 | 44 | 1000 |  | s | false |\n| avg_pos_vertical_speed | sint16 | 45 | 1000 |  | m/s | false |\n| avg_neg_vertical_speed | sint16 | 46 | 1000 |  | m/s | false |\n| max_pos_vertical_speed | sint16 | 47 | 1000 |  | m/s | false |\n| max_neg_vertical_speed | sint16 | 48 | 1000 |  | m/s | false |\n| time_in_hr_zone | uint32 | 49 | 1000 |  | s | true |\n| time_in_speed_zone | uint32 | 50 | 1000 |  | s | true |\n| time_in_cadence_zone | uint32 | 51 | 1000 |  | s | true |\n| time_in_power_zone | uint32 | 52 | 1000 |  | s | true |\n| repetition_num | uint16 | 53 |  |  |  | false |\n| min_altitude | uint16 | 54 | 5 | 500 | m | false |\n| min_heart_rate | uint8 | 55 |  |  | bpm | false |\n| active_time | uint32 | 56 | 1000 |  | s | false |\n| wkt_step_index | message_index | 57 |  |  |  | false |\n| sport_event | sport_event | 58 |  |  |  | false |\n| avg_left_torque_effectiveness | uint8 | 59 | 2 |  | percent | false |\n| avg_right_torque_effectiveness | uint8 | 60 | 2 |  | percent | false |\n| avg_left_pedal_smoothness | uint8 | 61 | 2 |  | percent | false |\n| avg_right_pedal_smoothness | uint8 | 62 | 2 |  | percent | false |\n| avg_combined_pedal_smoothness | uint8 | 63 | 2 |  | percent | false |\n| status | segment_lap_status | 64 |  |  |  | false |\n| uuid | string | 65 |  |  |  | false |\n| avg_fractional_cadence | uint8 | 66 | 128 |  | rpm | false |\n| max_fractional_cadence | uint8 | 67 | 128 |  | rpm | false |\n| total_fractional_cycles | uint8 | 68 | 128 |  | cycles | false |\n| front_gear_shift_count | uint16 | 69 |  |  |  | false |\n| rear_gear_shift_count | uint16 | 70 |  |  |  | false |\n| time_standing | uint32 | 71 | 1000 |  | s | false |\n| stand_count | uint16 | 72 |  |  |  | false |\n| avg_left_pco | sint8 | 73 |  |  | mm | false |\n| avg_right_pco | sint8 | 74 |  |  | mm | false |\n| avg_left_power_phase | uint8 | 75 | 0.7111111 |  | degrees | true |\n| avg_left_power_phase_peak | uint8 | 76 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase | uint8 | 77 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase_peak | uint8 | 78 | 0.7111111 |  | degrees | true |\n| avg_power_position | uint16 | 79 |  |  | watts | true |\n| max_power_position | uint16 | 80 |  |  | watts | true |\n| avg_cadence_position | uint8 | 81 |  |  | rpm | true |\n| max_cadence_position | uint8 | 82 |  |  | rpm | true |\n| manufacturer | manufacturer | 83 |  |  |  | false |\n| total_grit | float32 | 84 |  |  | kGrit | false |\n| total_flow | float32 | 85 |  |  | Flow | false |\n| avg_grit | float32 | 86 |  |  | kGrit | false |\n| avg_flow | float32 | 87 |  |  | Flow | false |\n| total_fractional_ascent | uint8 | 89 | 100 |  | m | false |\n| total_fractional_descent | uint8 | 90 | 100 |  | m | false |\n| enhanced_avg_altitude | uint32 | 91 | 5 | 500 | m | false |\n| enhanced_max_altitude | uint32 | 92 | 5 | 500 | m | false |\n| enhanced_min_altitude | uint32 | 93 | 5 | 500 | m | false |\n| timestamp | date_time | 253 |  |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SegmentLap.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SegmentLap","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SegmentLap.html#t:t/0","title":"ExtFit.Profile.Messages.SegmentLap.t/0","type":"type"},{"doc":"Message: `:segment_leaderboard_entry` identified by num=149","ref":"ExtFit.Profile.Messages.SegmentLeaderboardEntry.html","title":"ExtFit.Profile.Messages.SegmentLeaderboardEntry","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| name | string | 0 |  |  |  | false |\n| type | segment_leaderboard_type | 1 |  |  |  | false |\n| group_primary_key | uint32 | 2 |  |  |  | false |\n| activity_id | uint32 | 3 |  |  |  | false |\n| segment_time | uint32 | 4 | 1000 |  | s | false |\n| activity_id_string | string | 5 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SegmentLeaderboardEntry.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SegmentLeaderboardEntry","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SegmentLeaderboardEntry.html#t:t/0","title":"ExtFit.Profile.Messages.SegmentLeaderboardEntry.t/0","type":"type"},{"doc":"Message: `:segment_point` identified by num=150","ref":"ExtFit.Profile.Messages.SegmentPoint.html","title":"ExtFit.Profile.Messages.SegmentPoint","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| position_lat | sint32 | 1 |  |  | semicircles | false |\n| position_long | sint32 | 2 |  |  | semicircles | false |\n| distance | uint32 | 3 | 100 |  | m | false |\n| altitude | uint16 | 4 | 5 | 500 | m | false |\n| leader_time | uint32 | 5 | 1000 |  | s | true |\n| enhanced_altitude | uint32 | 6 | 5 | 500 | m | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SegmentPoint.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SegmentPoint","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SegmentPoint.html#t:t/0","title":"ExtFit.Profile.Messages.SegmentPoint.t/0","type":"type"},{"doc":"Message: `:session` identified by num=18","ref":"ExtFit.Profile.Messages.Session.html","title":"ExtFit.Profile.Messages.Session","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| event | event | 0 |  |  |  | false |\n| event_type | event_type | 1 |  |  |  | false |\n| start_time | date_time | 2 |  |  |  | false |\n| start_position_lat | sint32 | 3 |  |  | semicircles | false |\n| start_position_long | sint32 | 4 |  |  | semicircles | false |\n| sport | sport | 5 |  |  |  | false |\n| sub_sport | sub_sport | 6 |  |  |  | false |\n| total_elapsed_time | uint32 | 7 | 1000 |  | s | false |\n| total_timer_time | uint32 | 8 | 1000 |  | s | false |\n| total_distance | uint32 | 9 | 100 |  | m | false |\n| total_cycles | uint32 | 10 |  |  | cycles | false |\n| total_calories | uint16 | 11 |  |  | kcal | false |\n| total_fat_calories | uint16 | 13 |  |  | kcal | false |\n| avg_speed | uint16 | 14 | 1000 |  | m/s | false |\n| max_speed | uint16 | 15 | 1000 |  | m/s | false |\n| avg_heart_rate | uint8 | 16 |  |  | bpm | false |\n| max_heart_rate | uint8 | 17 |  |  | bpm | false |\n| avg_cadence | uint8 | 18 |  |  | rpm | false |\n| max_cadence | uint8 | 19 |  |  | rpm | false |\n| avg_power | uint16 | 20 |  |  | watts | false |\n| max_power | uint16 | 21 |  |  | watts | false |\n| total_ascent | uint16 | 22 |  |  | m | false |\n| total_descent | uint16 | 23 |  |  | m | false |\n| total_training_effect | uint8 | 24 | 10 |  |  | false |\n| first_lap_index | uint16 | 25 |  |  |  | false |\n| num_laps | uint16 | 26 |  |  |  | false |\n| event_group | uint8 | 27 |  |  |  | false |\n| trigger | session_trigger | 28 |  |  |  | false |\n| nec_lat | sint32 | 29 |  |  | semicircles | false |\n| nec_long | sint32 | 30 |  |  | semicircles | false |\n| swc_lat | sint32 | 31 |  |  | semicircles | false |\n| swc_long | sint32 | 32 |  |  | semicircles | false |\n| num_lengths | uint16 | 33 |  |  | lengths | false |\n| normalized_power | uint16 | 34 |  |  | watts | false |\n| training_stress_score | uint16 | 35 | 10 |  | tss | false |\n| intensity_factor | uint16 | 36 | 1000 |  | if | false |\n| left_right_balance | left_right_balance_100 | 37 |  |  |  | false |\n| end_position_lat | sint32 | 38 |  |  | semicircles | false |\n| end_position_long | sint32 | 39 |  |  | semicircles | false |\n| avg_stroke_count | uint32 | 41 | 10 |  | strokes/lap | false |\n| avg_stroke_distance | uint16 | 42 | 100 |  | m | false |\n| swim_stroke | swim_stroke | 43 |  |  | swim_stroke | false |\n| pool_length | uint16 | 44 | 100 |  | m | false |\n| threshold_power | uint16 | 45 |  |  | watts | false |\n| pool_length_unit | display_measure | 46 |  |  |  | false |\n| num_active_lengths | uint16 | 47 |  |  | lengths | false |\n| total_work | uint32 | 48 |  |  | J | false |\n| avg_altitude | uint16 | 49 | 5 | 500 | m | false |\n| max_altitude | uint16 | 50 | 5 | 500 | m | false |\n| gps_accuracy | uint8 | 51 |  |  | m | false |\n| avg_grade | sint16 | 52 | 100 |  | % | false |\n| avg_pos_grade | sint16 | 53 | 100 |  | % | false |\n| avg_neg_grade | sint16 | 54 | 100 |  | % | false |\n| max_pos_grade | sint16 | 55 | 100 |  | % | false |\n| max_neg_grade | sint16 | 56 | 100 |  | % | false |\n| avg_temperature | sint8 | 57 |  |  | C | false |\n| max_temperature | sint8 | 58 |  |  | C | false |\n| total_moving_time | uint32 | 59 | 1000 |  | s | false |\n| avg_pos_vertical_speed | sint16 | 60 | 1000 |  | m/s | false |\n| avg_neg_vertical_speed | sint16 | 61 | 1000 |  | m/s | false |\n| max_pos_vertical_speed | sint16 | 62 | 1000 |  | m/s | false |\n| max_neg_vertical_speed | sint16 | 63 | 1000 |  | m/s | false |\n| min_heart_rate | uint8 | 64 |  |  | bpm | false |\n| time_in_hr_zone | uint32 | 65 | 1000 |  | s | true |\n| time_in_speed_zone | uint32 | 66 | 1000 |  | s | true |\n| time_in_cadence_zone | uint32 | 67 | 1000 |  | s | true |\n| time_in_power_zone | uint32 | 68 | 1000 |  | s | true |\n| avg_lap_time | uint32 | 69 | 1000 |  | s | false |\n| best_lap_index | uint16 | 70 |  |  |  | false |\n| min_altitude | uint16 | 71 | 5 | 500 | m | false |\n| player_score | uint16 | 82 |  |  |  | false |\n| opponent_score | uint16 | 83 |  |  |  | false |\n| opponent_name | string | 84 |  |  |  | false |\n| stroke_count | uint16 | 85 |  |  | counts | true |\n| zone_count | uint16 | 86 |  |  | counts | true |\n| max_ball_speed | uint16 | 87 | 100 |  | m/s | false |\n| avg_ball_speed | uint16 | 88 | 100 |  | m/s | false |\n| avg_vertical_oscillation | uint16 | 89 | 10 |  | mm | false |\n| avg_stance_time_percent | uint16 | 90 | 100 |  | percent | false |\n| avg_stance_time | uint16 | 91 | 10 |  | ms | false |\n| avg_fractional_cadence | uint8 | 92 | 128 |  | rpm | false |\n| max_fractional_cadence | uint8 | 93 | 128 |  | rpm | false |\n| total_fractional_cycles | uint8 | 94 | 128 |  | cycles | false |\n| avg_total_hemoglobin_conc | uint16 | 95 | 100 |  | g/dL | true |\n| min_total_hemoglobin_conc | uint16 | 96 | 100 |  | g/dL | true |\n| max_total_hemoglobin_conc | uint16 | 97 | 100 |  | g/dL | true |\n| avg_saturated_hemoglobin_percent | uint16 | 98 | 10 |  | % | true |\n| min_saturated_hemoglobin_percent | uint16 | 99 | 10 |  | % | true |\n| max_saturated_hemoglobin_percent | uint16 | 100 | 10 |  | % | true |\n| avg_left_torque_effectiveness | uint8 | 101 | 2 |  | percent | false |\n| avg_right_torque_effectiveness | uint8 | 102 | 2 |  | percent | false |\n| avg_left_pedal_smoothness | uint8 | 103 | 2 |  | percent | false |\n| avg_right_pedal_smoothness | uint8 | 104 | 2 |  | percent | false |\n| avg_combined_pedal_smoothness | uint8 | 105 | 2 |  | percent | false |\n| sport_profile_name | string | 110 |  |  |  | false |\n| sport_index | uint8 | 111 |  |  |  | false |\n| time_standing | uint32 | 112 | 1000 |  | s | false |\n| stand_count | uint16 | 113 |  |  |  | false |\n| avg_left_pco | sint8 | 114 |  |  | mm | false |\n| avg_right_pco | sint8 | 115 |  |  | mm | false |\n| avg_left_power_phase | uint8 | 116 | 0.7111111 |  | degrees | true |\n| avg_left_power_phase_peak | uint8 | 117 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase | uint8 | 118 | 0.7111111 |  | degrees | true |\n| avg_right_power_phase_peak | uint8 | 119 | 0.7111111 |  | degrees | true |\n| avg_power_position | uint16 | 120 |  |  | watts | true |\n| max_power_position | uint16 | 121 |  |  | watts | true |\n| avg_cadence_position | uint8 | 122 |  |  | rpm | true |\n| max_cadence_position | uint8 | 123 |  |  | rpm | true |\n| enhanced_avg_speed | uint32 | 124 | 1000 |  | m/s | false |\n| enhanced_max_speed | uint32 | 125 | 1000 |  | m/s | false |\n| enhanced_avg_altitude | uint32 | 126 | 5 | 500 | m | false |\n| enhanced_min_altitude | uint32 | 127 | 5 | 500 | m | false |\n| enhanced_max_altitude | uint32 | 128 | 5 | 500 | m | false |\n| avg_lev_motor_power | uint16 | 129 |  |  | watts | false |\n| max_lev_motor_power | uint16 | 130 |  |  | watts | false |\n| lev_battery_consumption | uint8 | 131 | 2 |  | percent | false |\n| avg_vertical_ratio | uint16 | 132 | 100 |  | percent | false |\n| avg_stance_time_balance | uint16 | 133 | 100 |  | percent | false |\n| avg_step_length | uint16 | 134 | 10 |  | mm | false |\n| total_anaerobic_training_effect | uint8 | 137 | 10 |  |  | false |\n| avg_vam | uint16 | 139 | 1000 |  | m/s | false |\n| avg_depth | uint32 | 140 | 1000 |  | m | false |\n| max_depth | uint32 | 141 | 1000 |  | m | false |\n| surface_interval | uint32 | 142 | 1 |  | s | false |\n| start_cns | uint8 | 143 | 1 |  | percent | false |\n| end_cns | uint8 | 144 | 1 |  | percent | false |\n| start_n2 | uint16 | 145 | 1 |  | percent | false |\n| end_n2 | uint16 | 146 | 1 |  | percent | false |\n| avg_respiration_rate | uint8 | 147 |  |  |  | false |\n| max_respiration_rate | uint8 | 148 |  |  |  | false |\n| min_respiration_rate | uint8 | 149 |  |  |  | false |\n| min_temperature | sint8 | 150 |  |  | C | false |\n| o2_toxicity | uint16 | 155 |  |  | OTUs | false |\n| dive_number | uint32 | 156 |  |  |  | false |\n| training_load_peak | sint32 | 168 | 65536 |  |  | false |\n| enhanced_avg_respiration_rate | uint16 | 169 | 100 |  | Breaths/min | false |\n| enhanced_max_respiration_rate | uint16 | 170 | 100 |  | Breaths/min | false |\n| enhanced_min_respiration_rate | uint16 | 180 | 100 |  |  | false |\n| total_grit | float32 | 181 |  |  | kGrit | false |\n| total_flow | float32 | 182 |  |  | Flow | false |\n| jump_count | uint16 | 183 |  |  |  | false |\n| avg_grit | float32 | 186 |  |  | kGrit | false |\n| avg_flow | float32 | 187 |  |  | Flow | false |\n| avg_spo2 | uint8 | 194 |  |  | percent | false |\n| avg_stress | uint8 | 195 |  |  | percent | false |\n| sdrr_hrv | uint8 | 197 |  |  | mS | false |\n| rmssd_hrv | uint8 | 198 |  |  | mS | false |\n| total_fractional_ascent | uint8 | 199 | 100 |  | m | false |\n| total_fractional_descent | uint8 | 200 | 100 |  | m | false |\n| avg_core_temperature | uint16 | 208 | 100 |  | C | false |\n| min_core_temperature | uint16 | 209 | 100 |  | C | false |\n| max_core_temperature | uint16 | 210 | 100 |  | C | false |\n| timestamp | date_time | 253 |  |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Session.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Session","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Session.html#t:t/0","title":"ExtFit.Profile.Messages.Session.t/0","type":"type"},{"doc":"Message: `:set` identified by num=225","ref":"ExtFit.Profile.Messages.Set.html","title":"ExtFit.Profile.Messages.Set","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| duration | uint32 | 0 | 1000 |  | s | false |\n| repetitions | uint16 | 3 |  |  |  | false |\n| weight | uint16 | 4 | 16 |  | kg | false |\n| set_type | set_type | 5 |  |  |  | false |\n| start_time | date_time | 6 |  |  |  | false |\n| category | exercise_category | 7 |  |  |  | true |\n| category_subtype | uint16 | 8 |  |  |  | true |\n| weight_display_unit | fit_base_unit | 9 |  |  |  | false |\n| message_index | message_index | 10 |  |  |  | false |\n| wkt_step_index | message_index | 11 |  |  |  | false |\n| timestamp | date_time | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Set.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Set","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Set.html#t:t/0","title":"ExtFit.Profile.Messages.Set.t/0","type":"type"},{"doc":"Message: `:slave_device` identified by num=106","ref":"ExtFit.Profile.Messages.SlaveDevice.html","title":"ExtFit.Profile.Messages.SlaveDevice","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| manufacturer | manufacturer | 0 |  |  |  | false |\n| product | uint16 | 1 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SlaveDevice.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SlaveDevice","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SlaveDevice.html#t:t/0","title":"ExtFit.Profile.Messages.SlaveDevice.t/0","type":"type"},{"doc":"Message: `:sleep_assessment` identified by num=346","ref":"ExtFit.Profile.Messages.SleepAssessment.html","title":"ExtFit.Profile.Messages.SleepAssessment","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| combined_awake_score | uint8 | 0 |  |  |  | false |\n| awake_time_score | uint8 | 1 |  |  |  | false |\n| awakenings_count_score | uint8 | 2 |  |  |  | false |\n| deep_sleep_score | uint8 | 3 |  |  |  | false |\n| sleep_duration_score | uint8 | 4 |  |  |  | false |\n| light_sleep_score | uint8 | 5 |  |  |  | false |\n| overall_sleep_score | uint8 | 6 |  |  |  | false |\n| sleep_quality_score | uint8 | 7 |  |  |  | false |\n| sleep_recovery_score | uint8 | 8 |  |  |  | false |\n| rem_sleep_score | uint8 | 9 |  |  |  | false |\n| sleep_restlessness_score | uint8 | 10 |  |  |  | false |\n| awakenings_count | uint8 | 11 |  |  |  | false |\n| interruptions_score | uint8 | 14 |  |  |  | false |\n| average_stress_during_sleep | uint16 | 15 | 100 |  |  | false |","ref":"ExtFit.Profile.Messages.SleepAssessment.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SleepAssessment","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SleepAssessment.html#t:t/0","title":"ExtFit.Profile.Messages.SleepAssessment.t/0","type":"type"},{"doc":"Message: `:sleep_level` identified by num=275","ref":"ExtFit.Profile.Messages.SleepLevel.html","title":"ExtFit.Profile.Messages.SleepLevel","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sleep_level | sleep_level | 0 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.SleepLevel.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SleepLevel","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SleepLevel.html#t:t/0","title":"ExtFit.Profile.Messages.SleepLevel.t/0","type":"type"},{"doc":"Message: `:software` identified by num=35","ref":"ExtFit.Profile.Messages.Software.html","title":"ExtFit.Profile.Messages.Software","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| version | uint16 | 3 | 100 |  |  | false |\n| part_number | string | 5 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Software.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Software","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Software.html#t:t/0","title":"ExtFit.Profile.Messages.Software.t/0","type":"type"},{"doc":"Message: `:speed_zone` identified by num=53","ref":"ExtFit.Profile.Messages.SpeedZone.html","title":"ExtFit.Profile.Messages.SpeedZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| high_value | uint16 | 0 | 1000 |  | m/s | false |\n| name | string | 1 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SpeedZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SpeedZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SpeedZone.html#t:t/0","title":"ExtFit.Profile.Messages.SpeedZone.t/0","type":"type"},{"doc":"Message: `:split` identified by num=312","ref":"ExtFit.Profile.Messages.Split.html","title":"ExtFit.Profile.Messages.Split","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| split_type | split_type | 0 |  |  |  | false |\n| total_elapsed_time | uint32 | 1 | 1000 |  | s | false |\n| total_timer_time | uint32 | 2 | 1000 |  | s | false |\n| total_distance | uint32 | 3 | 100 |  | m | false |\n| avg_speed | uint32 | 4 | 1000 |  | m/s | false |\n| start_time | date_time | 9 |  |  |  | false |\n| total_ascent | uint16 | 13 |  |  | m | false |\n| total_descent | uint16 | 14 |  |  | m | false |\n| start_position_lat | sint32 | 21 |  |  | semicircles | false |\n| start_position_long | sint32 | 22 |  |  | semicircles | false |\n| end_position_lat | sint32 | 23 |  |  | semicircles | false |\n| end_position_long | sint32 | 24 |  |  | semicircles | false |\n| max_speed | uint32 | 25 | 1000 |  | m/s | false |\n| avg_vert_speed | sint32 | 26 | 1000 |  | m/s | false |\n| end_time | date_time | 27 |  |  |  | false |\n| total_calories | uint32 | 28 |  |  | kcal | false |\n| start_elevation | uint32 | 74 | 5 | 500 | m | false |\n| total_moving_time | uint32 | 110 | 1000 |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Split.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Split","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Split.html#t:t/0","title":"ExtFit.Profile.Messages.Split.t/0","type":"type"},{"doc":"Message: `:split_summary` identified by num=313","ref":"ExtFit.Profile.Messages.SplitSummary.html","title":"ExtFit.Profile.Messages.SplitSummary","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| split_type | split_type | 0 |  |  |  | false |\n| num_splits | uint16 | 3 |  |  |  | false |\n| total_timer_time | uint32 | 4 | 1000 |  | s | false |\n| total_distance | uint32 | 5 | 100 |  | m | false |\n| avg_speed | uint32 | 6 | 1000 |  | m/s | false |\n| max_speed | uint32 | 7 | 1000 |  | m/s | false |\n| total_ascent | uint16 | 8 |  |  | m | false |\n| total_descent | uint16 | 9 |  |  | m | false |\n| avg_heart_rate | uint8 | 10 |  |  | bpm | false |\n| max_heart_rate | uint8 | 11 |  |  | bpm | false |\n| avg_vert_speed | sint32 | 12 | 1000 |  | m/s | false |\n| total_calories | uint32 | 13 |  |  | kcal | false |\n| total_moving_time | uint32 | 77 | 1000 |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.SplitSummary.html#module-fields","title":"Fields - ExtFit.Profile.Messages.SplitSummary","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.SplitSummary.html#t:t/0","title":"ExtFit.Profile.Messages.SplitSummary.t/0","type":"type"},{"doc":"Message: `:spo2_data` identified by num=269","ref":"ExtFit.Profile.Messages.Spo2Data.html","title":"ExtFit.Profile.Messages.Spo2Data","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| reading_spo2 | uint8 | 0 | 1 |  | percent | false |\n| reading_confidence | uint8 | 1 | 1 |  |  | false |\n| mode | spo2_measurement_type | 2 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.Spo2Data.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Spo2Data","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Spo2Data.html#t:t/0","title":"ExtFit.Profile.Messages.Spo2Data.t/0","type":"type"},{"doc":"Message: `:sport` identified by num=12","ref":"ExtFit.Profile.Messages.Sport.html","title":"ExtFit.Profile.Messages.Sport","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sport | sport | 0 |  |  |  | false |\n| sub_sport | sub_sport | 1 |  |  |  | false |\n| name | string | 3 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Sport.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Sport","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Sport.html#t:t/0","title":"ExtFit.Profile.Messages.Sport.t/0","type":"type"},{"doc":"Message: `:stress_level` identified by num=227","ref":"ExtFit.Profile.Messages.StressLevel.html","title":"ExtFit.Profile.Messages.StressLevel","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| stress_level_value | sint16 | 0 |  |  |  | false |\n| stress_level_time | date_time | 1 |  |  | s | false |","ref":"ExtFit.Profile.Messages.StressLevel.html#module-fields","title":"Fields - ExtFit.Profile.Messages.StressLevel","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.StressLevel.html#t:t/0","title":"ExtFit.Profile.Messages.StressLevel.t/0","type":"type"},{"doc":"Message: `:tank_summary` identified by num=323","ref":"ExtFit.Profile.Messages.TankSummary.html","title":"ExtFit.Profile.Messages.TankSummary","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sensor | ant_channel_id | 0 |  |  |  | false |\n| start_pressure | uint16 | 1 | 100 |  | bar | false |\n| end_pressure | uint16 | 2 | 100 |  | bar | false |\n| volume_used | uint32 | 3 | 100 |  | L | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.TankSummary.html#module-fields","title":"Fields - ExtFit.Profile.Messages.TankSummary","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.TankSummary.html#t:t/0","title":"ExtFit.Profile.Messages.TankSummary.t/0","type":"type"},{"doc":"Message: `:tank_update` identified by num=319","ref":"ExtFit.Profile.Messages.TankUpdate.html","title":"ExtFit.Profile.Messages.TankUpdate","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sensor | ant_channel_id | 0 |  |  |  | false |\n| pressure | uint16 | 1 | 100 |  | bar | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.TankUpdate.html#module-fields","title":"Fields - ExtFit.Profile.Messages.TankUpdate","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.TankUpdate.html#t:t/0","title":"ExtFit.Profile.Messages.TankUpdate.t/0","type":"type"},{"doc":"Message: `:three_d_sensor_calibration` identified by num=167","ref":"ExtFit.Profile.Messages.ThreeDSensorCalibration.html","title":"ExtFit.Profile.Messages.ThreeDSensorCalibration","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sensor_type | sensor_type | 0 |  |  |  | false |\n| calibration_factor | uint32 | 1 |  |  |  | false |\n| calibration_divisor | uint32 | 2 |  |  | counts | false |\n| level_shift | uint32 | 3 |  |  |  | false |\n| offset_cal | sint32 | 4 |  |  |  | 3 |\n| orientation_matrix | sint32 | 5 | 65535 |  |  | 9 |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.ThreeDSensorCalibration.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ThreeDSensorCalibration","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ThreeDSensorCalibration.html#t:t/0","title":"ExtFit.Profile.Messages.ThreeDSensorCalibration.t/0","type":"type"},{"doc":"Message: `:time_in_zone` identified by num=216","ref":"ExtFit.Profile.Messages.TimeInZone.html","title":"ExtFit.Profile.Messages.TimeInZone","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| reference_mesg | mesg_num | 0 |  |  |  | false |\n| reference_index | message_index | 1 |  |  |  | false |\n| time_in_hr_zone | uint32 | 2 | 1000 |  | s | true |\n| time_in_speed_zone | uint32 | 3 | 1000 |  | s | true |\n| time_in_cadence_zone | uint32 | 4 | 1000 |  | s | true |\n| time_in_power_zone | uint32 | 5 | 1000 |  | s | true |\n| hr_zone_high_boundary | uint8 | 6 |  |  | bpm | true |\n| speed_zone_high_boundary | uint16 | 7 | 1000 |  | m/s | true |\n| cadence_zone_high_bondary | uint8 | 8 |  |  | rpm | true |\n| power_zone_high_boundary | uint16 | 9 |  |  | watts | true |\n| hr_calc_type | hr_zone_calc | 10 |  |  |  | false |\n| max_heart_rate | uint8 | 11 |  |  |  | false |\n| resting_heart_rate | uint8 | 12 |  |  |  | false |\n| threshold_heart_rate | uint8 | 13 |  |  |  | false |\n| pwr_calc_type | pwr_zone_calc | 14 |  |  |  | false |\n| functional_threshold_power | uint16 | 15 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.TimeInZone.html#module-fields","title":"Fields - ExtFit.Profile.Messages.TimeInZone","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.TimeInZone.html#t:t/0","title":"ExtFit.Profile.Messages.TimeInZone.t/0","type":"type"},{"doc":"Message: `:timestamp_correlation` identified by num=162","ref":"ExtFit.Profile.Messages.TimestampCorrelation.html","title":"ExtFit.Profile.Messages.TimestampCorrelation","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| fractional_timestamp | uint16 | 0 | 32768 |  | s | false |\n| system_timestamp | date_time | 1 |  |  | s | false |\n| fractional_system_timestamp | uint16 | 2 | 32768 |  | s | false |\n| local_timestamp | local_date_time | 3 |  |  | s | false |\n| timestamp_ms | uint16 | 4 |  |  | ms | false |\n| system_timestamp_ms | uint16 | 5 |  |  | ms | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.TimestampCorrelation.html#module-fields","title":"Fields - ExtFit.Profile.Messages.TimestampCorrelation","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.TimestampCorrelation.html#t:t/0","title":"ExtFit.Profile.Messages.TimestampCorrelation.t/0","type":"type"},{"doc":"Message: `:totals` identified by num=33","ref":"ExtFit.Profile.Messages.Totals.html","title":"ExtFit.Profile.Messages.Totals","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timer_time | uint32 | 0 |  |  | s | false |\n| distance | uint32 | 1 |  |  | m | false |\n| calories | uint32 | 2 |  |  | kcal | false |\n| sport | sport | 3 |  |  |  | false |\n| elapsed_time | uint32 | 4 |  |  | s | false |\n| sessions | uint16 | 5 |  |  |  | false |\n| active_time | uint32 | 6 |  |  | s | false |\n| sport_index | uint8 | 9 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Totals.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Totals","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Totals.html#t:t/0","title":"ExtFit.Profile.Messages.Totals.t/0","type":"type"},{"doc":"Message: `:training_file` identified by num=72","ref":"ExtFit.Profile.Messages.TrainingFile.html","title":"ExtFit.Profile.Messages.TrainingFile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| type | file | 0 |  |  |  | false |\n| manufacturer | manufacturer | 1 |  |  |  | false |\n| product | uint16 | 2 |  |  |  | false |\n| serial_number | uint32z | 3 |  |  |  | false |\n| time_created | date_time | 4 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.TrainingFile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.TrainingFile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.TrainingFile.html#t:t/0","title":"ExtFit.Profile.Messages.TrainingFile.t/0","type":"type"},{"doc":"Message: `:user_profile` identified by num=3","ref":"ExtFit.Profile.Messages.UserProfile.html","title":"ExtFit.Profile.Messages.UserProfile","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| friendly_name | string | 0 |  |  |  | false |\n| gender | gender | 1 |  |  |  | false |\n| age | uint8 | 2 |  |  | years | false |\n| height | uint8 | 3 | 100 |  | m | false |\n| weight | uint16 | 4 | 10 |  | kg | false |\n| language | language | 5 |  |  |  | false |\n| elev_setting | display_measure | 6 |  |  |  | false |\n| weight_setting | display_measure | 7 |  |  |  | false |\n| resting_heart_rate | uint8 | 8 |  |  | bpm | false |\n| default_max_running_heart_rate | uint8 | 9 |  |  | bpm | false |\n| default_max_biking_heart_rate | uint8 | 10 |  |  | bpm | false |\n| default_max_heart_rate | uint8 | 11 |  |  | bpm | false |\n| hr_setting | display_heart | 12 |  |  |  | false |\n| speed_setting | display_measure | 13 |  |  |  | false |\n| dist_setting | display_measure | 14 |  |  |  | false |\n| power_setting | display_power | 16 |  |  |  | false |\n| activity_class | activity_class | 17 |  |  |  | false |\n| position_setting | display_position | 18 |  |  |  | false |\n| temperature_setting | display_measure | 21 |  |  |  | false |\n| local_id | user_local_id | 22 |  |  |  | false |\n| global_id | byte | 23 |  |  |  | 6 |\n| wake_time | localtime_into_day | 28 |  |  |  | false |\n| sleep_time | localtime_into_day | 29 |  |  |  | false |\n| height_setting | display_measure | 30 |  |  |  | false |\n| user_running_step_length | uint16 | 31 | 1000 |  | m | false |\n| user_walking_step_length | uint16 | 32 | 1000 |  | m | false |\n| depth_setting | display_measure | 47 |  |  |  | false |\n| dive_count | uint32 | 49 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.UserProfile.html#module-fields","title":"Fields - ExtFit.Profile.Messages.UserProfile","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.UserProfile.html#t:t/0","title":"ExtFit.Profile.Messages.UserProfile.t/0","type":"type"},{"doc":"Message: `:video` identified by num=184","ref":"ExtFit.Profile.Messages.Video.html","title":"ExtFit.Profile.Messages.Video","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| url | string | 0 |  |  |  | false |\n| hosting_provider | string | 1 |  |  |  | false |\n| duration | uint32 | 2 |  |  | ms | false |","ref":"ExtFit.Profile.Messages.Video.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Video","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Video.html#t:t/0","title":"ExtFit.Profile.Messages.Video.t/0","type":"type"},{"doc":"Message: `:video_clip` identified by num=187","ref":"ExtFit.Profile.Messages.VideoClip.html","title":"ExtFit.Profile.Messages.VideoClip","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| clip_number | uint16 | 0 |  |  |  | false |\n| start_timestamp | date_time | 1 |  |  |  | false |\n| start_timestamp_ms | uint16 | 2 |  |  |  | false |\n| end_timestamp | date_time | 3 |  |  |  | false |\n| end_timestamp_ms | uint16 | 4 |  |  |  | false |\n| clip_start | uint32 | 6 |  |  | ms | false |\n| clip_end | uint32 | 7 |  |  | ms | false |","ref":"ExtFit.Profile.Messages.VideoClip.html#module-fields","title":"Fields - ExtFit.Profile.Messages.VideoClip","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.VideoClip.html#t:t/0","title":"ExtFit.Profile.Messages.VideoClip.t/0","type":"type"},{"doc":"Message: `:video_description` identified by num=186","ref":"ExtFit.Profile.Messages.VideoDescription.html","title":"ExtFit.Profile.Messages.VideoDescription","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| message_count | uint16 | 0 |  |  |  | false |\n| text | string | 1 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.VideoDescription.html#module-fields","title":"Fields - ExtFit.Profile.Messages.VideoDescription","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.VideoDescription.html#t:t/0","title":"ExtFit.Profile.Messages.VideoDescription.t/0","type":"type"},{"doc":"Message: `:video_frame` identified by num=169","ref":"ExtFit.Profile.Messages.VideoFrame.html","title":"ExtFit.Profile.Messages.VideoFrame","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| timestamp_ms | uint16 | 0 |  |  | ms | false |\n| frame_number | uint32 | 1 |  |  |  | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.VideoFrame.html#module-fields","title":"Fields - ExtFit.Profile.Messages.VideoFrame","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.VideoFrame.html#t:t/0","title":"ExtFit.Profile.Messages.VideoFrame.t/0","type":"type"},{"doc":"Message: `:video_title` identified by num=185","ref":"ExtFit.Profile.Messages.VideoTitle.html","title":"ExtFit.Profile.Messages.VideoTitle","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| message_count | uint16 | 0 |  |  |  | false |\n| text | string | 1 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.VideoTitle.html#module-fields","title":"Fields - ExtFit.Profile.Messages.VideoTitle","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.VideoTitle.html#t:t/0","title":"ExtFit.Profile.Messages.VideoTitle.t/0","type":"type"},{"doc":"Message: `:watchface_settings` identified by num=159","ref":"ExtFit.Profile.Messages.WatchfaceSettings.html","title":"ExtFit.Profile.Messages.WatchfaceSettings","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| mode | watchface_mode | 0 |  |  |  | false |\n| layout | byte | 1 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.WatchfaceSettings.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WatchfaceSettings","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WatchfaceSettings.html#t:t/0","title":"ExtFit.Profile.Messages.WatchfaceSettings.t/0","type":"type"},{"doc":"Message: `:weather_alert` identified by num=129","ref":"ExtFit.Profile.Messages.WeatherAlert.html","title":"ExtFit.Profile.Messages.WeatherAlert","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| report_id | string | 0 |  |  |  | false |\n| issue_time | date_time | 1 |  |  |  | false |\n| expire_time | date_time | 2 |  |  |  | false |\n| severity | weather_severity | 3 |  |  |  | false |\n| type | weather_severe_type | 4 |  |  |  | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.WeatherAlert.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WeatherAlert","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WeatherAlert.html#t:t/0","title":"ExtFit.Profile.Messages.WeatherAlert.t/0","type":"type"},{"doc":"Message: `:weather_conditions` identified by num=128","ref":"ExtFit.Profile.Messages.WeatherConditions.html","title":"ExtFit.Profile.Messages.WeatherConditions","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| weather_report | weather_report | 0 |  |  |  | false |\n| temperature | sint8 | 1 |  |  | C | false |\n| condition | weather_status | 2 |  |  |  | false |\n| wind_direction | uint16 | 3 |  |  | degrees | false |\n| wind_speed | uint16 | 4 | 1000 |  | m/s | false |\n| precipitation_probability | uint8 | 5 |  |  |  | false |\n| temperature_feels_like | sint8 | 6 |  |  | C | false |\n| relative_humidity | uint8 | 7 |  |  |  | false |\n| location | string | 8 |  |  |  | false |\n| observed_at_time | date_time | 9 |  |  |  | false |\n| observed_location_lat | sint32 | 10 |  |  | semicircles | false |\n| observed_location_long | sint32 | 11 |  |  | semicircles | false |\n| day_of_week | day_of_week | 12 |  |  |  | false |\n| high_temperature | sint8 | 13 |  |  | C | false |\n| low_temperature | sint8 | 14 |  |  | C | false |\n| timestamp | date_time | 253 |  |  |  | false |","ref":"ExtFit.Profile.Messages.WeatherConditions.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WeatherConditions","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WeatherConditions.html#t:t/0","title":"ExtFit.Profile.Messages.WeatherConditions.t/0","type":"type"},{"doc":"Message: `:weight_scale` identified by num=30","ref":"ExtFit.Profile.Messages.WeightScale.html","title":"ExtFit.Profile.Messages.WeightScale","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| weight | weight | 0 | 100 |  | kg | false |\n| percent_fat | uint16 | 1 | 100 |  | % | false |\n| percent_hydration | uint16 | 2 | 100 |  | % | false |\n| visceral_fat_mass | uint16 | 3 | 100 |  | kg | false |\n| bone_mass | uint16 | 4 | 100 |  | kg | false |\n| muscle_mass | uint16 | 5 | 100 |  | kg | false |\n| basal_met | uint16 | 7 | 4 |  | kcal/day | false |\n| physique_rating | uint8 | 8 |  |  |  | false |\n| active_met | uint16 | 9 | 4 |  | kcal/day | false |\n| metabolic_age | uint8 | 10 |  |  | years | false |\n| visceral_fat_rating | uint8 | 11 |  |  |  | false |\n| user_profile_index | message_index | 12 |  |  |  | false |\n| bmi | uint16 | 13 | 10 |  | kg/m^2 | false |\n| timestamp | date_time | 253 |  |  | s | false |","ref":"ExtFit.Profile.Messages.WeightScale.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WeightScale","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WeightScale.html#t:t/0","title":"ExtFit.Profile.Messages.WeightScale.t/0","type":"type"},{"doc":"Message: `:workout` identified by num=26","ref":"ExtFit.Profile.Messages.Workout.html","title":"ExtFit.Profile.Messages.Workout","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sport | sport | 4 |  |  |  | false |\n| capabilities | workout_capabilities | 5 |  |  |  | false |\n| num_valid_steps | uint16 | 6 |  |  |  | false |\n| wkt_name | string | 8 |  |  |  | false |\n| sub_sport | sub_sport | 11 |  |  |  | false |\n| pool_length | uint16 | 14 | 100 |  | m | false |\n| pool_length_unit | display_measure | 15 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.Workout.html#module-fields","title":"Fields - ExtFit.Profile.Messages.Workout","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.Workout.html#t:t/0","title":"ExtFit.Profile.Messages.Workout.t/0","type":"type"},{"doc":"Message: `:workout_session` identified by num=158","ref":"ExtFit.Profile.Messages.WorkoutSession.html","title":"ExtFit.Profile.Messages.WorkoutSession","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| sport | sport | 0 |  |  |  | false |\n| sub_sport | sub_sport | 1 |  |  |  | false |\n| num_valid_steps | uint16 | 2 |  |  |  | false |\n| first_step_index | uint16 | 3 |  |  |  | false |\n| pool_length | uint16 | 4 | 100 |  | m | false |\n| pool_length_unit | display_measure | 5 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.WorkoutSession.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WorkoutSession","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WorkoutSession.html#t:t/0","title":"ExtFit.Profile.Messages.WorkoutSession.t/0","type":"type"},{"doc":"Message: `:workout_step` identified by num=27","ref":"ExtFit.Profile.Messages.WorkoutStep.html","title":"ExtFit.Profile.Messages.WorkoutStep","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| wkt_step_name | string | 0 |  |  |  | false |\n| duration_type | wkt_step_duration | 1 |  |  |  | false |\n| duration_value | uint32 | 2 |  |  |  | false |\n| target_type | wkt_step_target | 3 |  |  |  | false |\n| target_value | uint32 | 4 |  |  |  | false |\n| custom_target_value_low | uint32 | 5 |  |  |  | false |\n| custom_target_value_high | uint32 | 6 |  |  |  | false |\n| intensity | intensity | 7 |  |  |  | false |\n| notes | string | 8 |  |  |  | false |\n| equipment | workout_equipment | 9 |  |  |  | false |\n| exercise_category | exercise_category | 10 |  |  |  | false |\n| exercise_name | uint16 | 11 |  |  |  | false |\n| exercise_weight | uint16 | 12 | 100 |  | kg | false |\n| weight_display_unit | fit_base_unit | 13 |  |  |  | false |\n| secondary_target_type | wkt_step_target | 19 |  |  |  | false |\n| secondary_target_value | uint32 | 20 |  |  |  | false |\n| secondary_custom_target_value_low | uint32 | 21 |  |  |  | false |\n| secondary_custom_target_value_high | uint32 | 22 |  |  |  | false |\n| message_index | message_index | 254 |  |  |  | false |","ref":"ExtFit.Profile.Messages.WorkoutStep.html#module-fields","title":"Fields - ExtFit.Profile.Messages.WorkoutStep","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.WorkoutStep.html#t:t/0","title":"ExtFit.Profile.Messages.WorkoutStep.t/0","type":"type"},{"doc":"Message: `:zones_target` identified by num=7","ref":"ExtFit.Profile.Messages.ZonesTarget.html","title":"ExtFit.Profile.Messages.ZonesTarget","type":"module"},{"doc":"| Name  | Type | Num | Scale | Offset | Units | Array |\n|------ | ---- |---- | ----- | ------ | ----- | ----- |\n| max_heart_rate | uint8 | 1 |  |  |  | false |\n| threshold_heart_rate | uint8 | 2 |  |  |  | false |\n| functional_threshold_power | uint16 | 3 |  |  |  | false |\n| hr_calc_type | hr_zone_calc | 5 |  |  |  | false |\n| pwr_calc_type | pwr_zone_calc | 7 |  |  |  | false |","ref":"ExtFit.Profile.Messages.ZonesTarget.html#module-fields","title":"Fields - ExtFit.Profile.Messages.ZonesTarget","type":"module"},{"doc":"","ref":"ExtFit.Profile.Messages.ZonesTarget.html#t:t/0","title":"ExtFit.Profile.Messages.ZonesTarget.t/0","type":"type"},{"doc":"FIT Types for profile from version: 21.126.00\n\n| Name | Base type |\n| ------ | ---- |\n| activity | enum |\n| activity_class | enum |\n| activity_level | enum |\n| activity_subtype | enum |\n| activity_type | enum |\n| analog_watchface_layout | enum |\n| ant_channel_id | uint32z |\n| ant_network | enum |\n| antplus_device_type | uint8 |\n| attitude_stage | enum |\n| attitude_validity | uint16 |\n| auto_activity_detect | uint32 |\n| auto_sync_frequency | enum |\n| autolap_trigger | enum |\n| autoscroll | enum |\n| backlight_mode | enum |\n| backlight_timeout | uint8 |\n| battery_status | uint8 |\n| bench_press_exercise_name | uint16 |\n| bike_light_beam_angle_mode | uint8 |\n| bike_light_network_config_type | enum |\n| ble_device_type | uint8 |\n| body_location | enum |\n| bool | enum |\n| bp_status | enum |\n| calf_raise_exercise_name | uint16 |\n| camera_event_type | enum |\n| camera_orientation_type | enum |\n| cardio_exercise_name | uint16 |\n| carry_exercise_name | uint16 |\n| ccr_setpoint_switch_mode | enum |\n| checksum | uint8 |\n| chop_exercise_name | uint16 |\n| climb_pro_event | enum |\n| comm_timeout_type | uint16 |\n| common_fields | enum |\n| connectivity_capabilities | uint32z |\n| core_exercise_name | uint16 |\n| course_capabilities | uint32z |\n| course_point | enum |\n| crunch_exercise_name | uint16 |\n| curl_exercise_name | uint16 |\n| date_mode | enum |\n| date_time | uint32 |\n| day_of_week | enum |\n| deadlift_exercise_name | uint16 |\n| device_index | uint8 |\n| digital_watchface_layout | enum |\n| display_heart | enum |\n| display_measure | enum |\n| display_orientation | enum |\n| display_position | enum |\n| display_power | enum |\n| dive_alarm_type | enum |\n| dive_alert | enum |\n| dive_backlight_mode | enum |\n| dive_gas_mode | enum |\n| dive_gas_status | enum |\n| event | enum |\n| event_type | enum |\n| exd_data_units | enum |\n| exd_descriptors | enum |\n| exd_display_type | enum |\n| exd_layout | enum |\n| exd_qualifiers | enum |\n| exercise_category | uint16 |\n| favero_product | uint16 |\n| file | enum |\n| file_flags | uint8z |\n| fit_base_type | uint8 |\n| fit_base_unit | uint16 |\n| fitness_equipment_state | enum |\n| flye_exercise_name | uint16 |\n| garmin_product | uint16 |\n| gas_consumption_rate_type | enum |\n| gender | enum |\n| goal | enum |\n| goal_recurrence | enum |\n| goal_source | enum |\n| hip_raise_exercise_name | uint16 |\n| hip_stability_exercise_name | uint16 |\n| hip_swing_exercise_name | uint16 |\n| hr_type | enum |\n| hr_zone_calc | enum |\n| hrv_status | enum |\n| hyperextension_exercise_name | uint16 |\n| intensity | enum |\n| language | enum |\n| language_bits_0 | uint8z |\n| language_bits_1 | uint8z |\n| language_bits_2 | uint8z |\n| language_bits_3 | uint8z |\n| language_bits_4 | uint8z |\n| lap_trigger | enum |\n| lateral_raise_exercise_name | uint16 |\n| left_right_balance | uint8 |\n| left_right_balance_100 | uint16 |\n| leg_curl_exercise_name | uint16 |\n| leg_raise_exercise_name | uint16 |\n| length_type | enum |\n| local_date_time | uint32 |\n| local_device_type | uint8 |\n| localtime_into_day | uint32 |\n| lunge_exercise_name | uint16 |\n| manufacturer | uint16 |\n| max_met_category | enum |\n| max_met_heart_rate_source | enum |\n| max_met_speed_source | enum |\n| mesg_count | enum |\n| mesg_num | uint16 |\n| message_index | uint16 |\n| no_fly_time_mode | enum |\n| olympic_lift_exercise_name | uint16 |\n| plank_exercise_name | uint16 |\n| plyo_exercise_name | uint16 |\n| power_phase_type | enum |\n| pull_up_exercise_name | uint16 |\n| push_up_exercise_name | uint16 |\n| pwr_zone_calc | enum |\n| radar_threat_level_type | enum |\n| rider_position_type | enum |\n| row_exercise_name | uint16 |\n| run_exercise_name | uint16 |\n| schedule | enum |\n| segment_delete_status | enum |\n| segment_lap_status | enum |\n| segment_leaderboard_type | enum |\n| segment_selection_type | enum |\n| sensor_type | enum |\n| session_trigger | enum |\n| set_type | uint8 |\n| shoulder_press_exercise_name | uint16 |\n| shoulder_stability_exercise_name | uint16 |\n| shrug_exercise_name | uint16 |\n| side | enum |\n| sit_up_exercise_name | uint16 |\n| sleep_level | enum |\n| source_type | enum |\n| split_type | enum |\n| spo2_measurement_type | enum |\n| sport | enum |\n| sport_bits_0 | uint8z |\n| sport_bits_1 | uint8z |\n| sport_bits_2 | uint8z |\n| sport_bits_3 | uint8z |\n| sport_bits_4 | uint8z |\n| sport_bits_5 | uint8z |\n| sport_bits_6 | uint8z |\n| sport_event | enum |\n| squat_exercise_name | uint16 |\n| stroke_type | enum |\n| sub_sport | enum |\n| supported_exd_screen_layouts | uint32z |\n| swim_stroke | enum |\n| switch | enum |\n| tap_sensitivity | enum |\n| time_into_day | uint32 |\n| time_mode | enum |\n| time_zone | enum |\n| timer_trigger | enum |\n| tissue_model_type | enum |\n| tone | enum |\n| total_body_exercise_name | uint16 |\n| triceps_extension_exercise_name | uint16 |\n| turn_type | enum |\n| user_local_id | uint16 |\n| version | uint16 |\n| warm_up_exercise_name | uint16 |\n| watchface_mode | enum |\n| water_type | enum |\n| weather_report | enum |\n| weather_severe_type | enum |\n| weather_severity | enum |\n| weather_status | enum |\n| weight | uint16 |\n| wkt_step_duration | enum |\n| wkt_step_target | enum |\n| workout_capabilities | uint32z |\n| workout_equipment | enum |\n| workout_hr | uint32 |\n| workout_power | uint32 |","ref":"ExtFit.Profile.Types.html","title":"ExtFit.Profile.Types","type":"module"},{"doc":"Get type by name","ref":"ExtFit.Profile.Types.html#by_name/1","title":"ExtFit.Profile.Types.by_name/1","type":"function"},{"doc":"Shortcut to quickly get common message num without going through mesg type","ref":"ExtFit.Profile.Types.html#mesg_num/1","title":"ExtFit.Profile.Types.mesg_num/1","type":"function"},{"doc":"","ref":"ExtFit.Profile.Types.html#types/0","title":"ExtFit.Profile.Types.types/0","type":"function"},{"doc":"","ref":"ExtFit.Record.html","title":"ExtFit.Record","type":"module"},{"doc":"Used for inspecting and debugging records. Don't depend on output from it.","ref":"ExtFit.Record.html#debug/1","title":"ExtFit.Record.debug/1","type":"function"},{"doc":"Filter record's fields by name.","ref":"ExtFit.Record.html#fields_by_name/2","title":"ExtFit.Record.fields_by_name/2","type":"function"},{"doc":"Gets name for given record based on its message type if possible.\nGracefully handles unknown messages.","ref":"ExtFit.Record.html#name/1","title":"ExtFit.Record.name/1","type":"function"},{"doc":"Filter records by message name and type.\n\nAvailable types: :data | :definition | :any","ref":"ExtFit.Record.html#records_by_message/3","title":"ExtFit.Record.records_by_message/3","type":"function"},{"doc":"Returns true if record is unknown.","ref":"ExtFit.Record.html#unknown?/1","title":"ExtFit.Record.unknown?/1","type":"function"},{"doc":"","ref":"ExtFit.Record.html#t:t/0","title":"ExtFit.Record.t/0","type":"type"},{"doc":"","ref":"ExtFit.Record.FitCrc.html","title":"ExtFit.Record.FitCrc","type":"module"},{"doc":"","ref":"ExtFit.Record.FitCrc.html#t:t/0","title":"ExtFit.Record.FitCrc.t/0","type":"type"},{"doc":"","ref":"ExtFit.Record.FitData.html","title":"ExtFit.Record.FitData","type":"module"},{"doc":"","ref":"ExtFit.Record.FitData.html#t:t/0","title":"ExtFit.Record.FitData.t/0","type":"type"},{"doc":"","ref":"ExtFit.Record.FitDefinition.html","title":"ExtFit.Record.FitDefinition","type":"module"},{"doc":"","ref":"ExtFit.Record.FitDefinition.html#t:t/0","title":"ExtFit.Record.FitDefinition.t/0","type":"type"},{"doc":"","ref":"ExtFit.Record.FitHeader.html","title":"ExtFit.Record.FitHeader","type":"module"},{"doc":"","ref":"ExtFit.Record.FitHeader.html#t:t/0","title":"ExtFit.Record.FitHeader.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.html","title":"ExtFit.Types","type":"module"},{"doc":"","ref":"ExtFit.Types.html#base_type_by_id/1","title":"ExtFit.Types.base_type_by_id/1","type":"function"},{"doc":"","ref":"ExtFit.Types.html#base_type_by_name/1","title":"ExtFit.Types.base_type_by_name/1","type":"function"},{"doc":"","ref":"ExtFit.Types.html#base_type_by_num/1","title":"ExtFit.Types.base_type_by_num/1","type":"function"},{"doc":"","ref":"ExtFit.Types.html#base_type_byte/0","title":"ExtFit.Types.base_type_byte/0","type":"function"},{"doc":"","ref":"ExtFit.Types.html#base_types/0","title":"ExtFit.Types.base_types/0","type":"function"},{"doc":"","ref":"ExtFit.Types.html#by_name/1","title":"ExtFit.Types.by_name/1","type":"function"},{"doc":"","ref":"ExtFit.Types.html#expected/2","title":"ExtFit.Types.expected/2","type":"function"},{"doc":"","ref":"ExtFit.Types.BaseType.html","title":"ExtFit.Types.BaseType","type":"module"},{"doc":"","ref":"ExtFit.Types.BaseType.html#t:t/0","title":"ExtFit.Types.BaseType.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.ComponentField.html","title":"ExtFit.Types.ComponentField","type":"module"},{"doc":"","ref":"ExtFit.Types.ComponentField.html#t:t/0","title":"ExtFit.Types.ComponentField.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.DevField.html","title":"ExtFit.Types.DevField","type":"module"},{"doc":"","ref":"ExtFit.Types.DevField.html#t:t/0","title":"ExtFit.Types.DevField.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.DevFieldDefinition.html","title":"ExtFit.Types.DevFieldDefinition","type":"module"},{"doc":"","ref":"ExtFit.Types.DevFieldDefinition.html#t:t/0","title":"ExtFit.Types.DevFieldDefinition.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.Field.html","title":"ExtFit.Types.Field","type":"module"},{"doc":"","ref":"ExtFit.Types.Field.html#t:t/0","title":"ExtFit.Types.Field.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.FieldData.html","title":"ExtFit.Types.FieldData","type":"module"},{"doc":"Used for inspecting and debugging records. Don't depend on output from it.","ref":"ExtFit.Types.FieldData.html#debug/1","title":"ExtFit.Types.FieldData.debug/1","type":"function"},{"doc":"","ref":"ExtFit.Types.FieldData.html#t:t/0","title":"ExtFit.Types.FieldData.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.FieldDefinition.html","title":"ExtFit.Types.FieldDefinition","type":"module"},{"doc":"","ref":"ExtFit.Types.FieldDefinition.html#t:t/0","title":"ExtFit.Types.FieldDefinition.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.FieldType.html","title":"ExtFit.Types.FieldType","type":"module"},{"doc":"","ref":"ExtFit.Types.FieldType.html#t:t/0","title":"ExtFit.Types.FieldType.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.FieldTypeValue.html","title":"ExtFit.Types.FieldTypeValue","type":"module"},{"doc":"","ref":"ExtFit.Types.FieldTypeValue.html#t:t/0","title":"ExtFit.Types.FieldTypeValue.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.MessageType.html","title":"ExtFit.Types.MessageType","type":"module"},{"doc":"","ref":"ExtFit.Types.MessageType.html#t:t/0","title":"ExtFit.Types.MessageType.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.ReferenceField.html","title":"ExtFit.Types.ReferenceField","type":"module"},{"doc":"","ref":"ExtFit.Types.ReferenceField.html#t:t/0","title":"ExtFit.Types.ReferenceField.t/0","type":"type"},{"doc":"","ref":"ExtFit.Types.Subfield.html","title":"ExtFit.Types.Subfield","type":"module"},{"doc":"","ref":"ExtFit.Types.Subfield.html#t:t/0","title":"ExtFit.Types.Subfield.t/0","type":"type"},{"doc":"# ExtFit\n\n[![Actions Status](https://github.com/arathunku/ext_fit/actions/workflows/elixir-build-and-test.yml/badge.svg)](https://github.com/arathunku/ext_fit/actions/workflows/elixir-build-and-test.yml) \n[![Hex.pm](https://img.shields.io/hexpm/v/ext_fit.svg?style=flat)](https://hex.pm/packages/ext_fit)\n[![Documentation](https://img.shields.io/badge/hex-docs-lightgreen.svg?style=flat)](https://hexdocs.pm/ext_fit)\n[![License](https://img.shields.io/hexpm/l/ext_fit.svg?style=flat)](https://github.com/arathunku/ext_fit/blob/main/LICENSE.md)\n\n<!-- @moduledoc -->\n\n`.fit` file decoder. See `ExtFit.Decode` module for more details and usage.\n\nIt's still in alpha-release and there's a slim chance that the format of returned\nstructs will change but if possible, will be avoided.\n\nCurrently used FIT profile can be seen in `ExtFit.Profile.Types` file.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `ext_fit` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ext_fit, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"```elixir\n{:ok, records} =\n  \"my-file.fit\"\n  |> File.read!()\n  |> ExtFit.Decode.decode()\n\n# print first record\nhd(record)\n```\n\nThe docs can be found at  .\n\nFIT structs are very large, you might want to take a look at\n[examples](https://github.com/arathunku/ext_fit/tree/main/examples) first!\n\nhttps://github.com/arathunku/ext_fit/assets/749393/4c16c3ff-ba47-472b-9323-c9285842c2a8\n\n(may not be visible on hexdocs, see [GitHub README](https://github.com/arathunku/ext_fit/tree/main?tab=readme-ov-file#usage))","ref":"readme.html#usage","title":"Usage - Overview","type":"extras"},{"doc":"Before contributing to this project, please read the CONTRIBUTING.md.","ref":"readme.html#contributing","title":"Contributing - Overview","type":"extras"},{"doc":"Copyright © 2024 Michal Forys\n\nThis project is licensed under the MIT license.","ref":"readme.html#license","title":"License - Overview","type":"extras"},{"doc":"# Changelog\n\n<!-- #","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"<!-- #","ref":"changelog.html#bug-fixes","title":"Bug fixes --> - Changelog","type":"extras"},{"doc":"<!-- #","ref":"changelog.html#enhancements","title":"Enhancements --> - Changelog","type":"extras"},{"doc":"","ref":"changelog.html#backwards-incompatible-changes","title":"Backwards incompatible changes --> - Changelog","type":"extras"},{"doc":"Init release","ref":"changelog.html#0-1-0-2024-03-29","title":"0.1.0 (2024-03-29) - Changelog","type":"extras"},{"doc":"# Contributing to ExtFit","ref":"contributing.html","title":"Contributing","type":"extras"},{"doc":"#","ref":"contributing.html#setup","title":"Setup - Contributing","type":"extras"},{"doc":"```sh\n# use your own fork \n$ git clone git@github.com:arathunku/ext_fit.git\n$ cd ext_fit\n$ mix deps.get\n# ensure everything works\n$ mix test \n# do your changes\n$ mix check\n```\n\n#","ref":"contributing.html#local-repository","title":"Local repository - Contributing","type":"extras"},{"doc":"Requires [`Nix` package manager](https://nixos.org/).\n\n1. Get new SDK from [developer.garmin.com](https://developer.garmin.com/fit/download/)\n1. Save `.zip` in \"sdks/\" directory and unzip it next to it with `fit-sdk-{{version}}`\n1. Run `scripts/profile-xlsx-as-csv`. This uses LibreOffice to convert `xlsx` to `csv`\n1. Update version in `scripts/gen-profile`\n1. Generate new profile files with `scripts/gen-profile`\n\n#","ref":"contributing.html#updating-to-new-sdk","title":"Updating to new SDK - Contributing","type":"extras"},{"doc":"Requires [`Nix` package manager](https://nixos.org/).\n\n1. Add new file to `test/support/files`\n1. Please use name {{YYYY}}-{{MM}}-{{DD}}-{{company}}-{{device}}-{{context}}.fit where date\n  should _mostly_ match date when the activity was recorded\n1. Optional:\n    - install [fitdecode](https://github.com/polyvertex/fitdecode) for `fitjson` command\n    - install [fitdump](https://github.com/dtcooper/python-fitparse) for `fitdump` command\n\n1. Run `scripts/generate-dumps-for-test-files`, this will use official fit2csv tool to dump `.csv` file,","ref":"contributing.html#add-new-test-fit-files","title":"Add new test FIT files - Contributing","type":"extras"},{"doc":"# MIT License\n\nCopyright (c) 2024 Michal Forys\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# TODO\n\nDecoder is usable but there's still a lot to do!\n\nAny help would be highly appreciated!\n\n- **!!!!! Creating and writing .fit files, this library doesn't have encoder**\n- Calculate CRC values\n- Streaming out processed records\n- Option to decode only specific messages. Example: [{:hr}]\n- Option to decode only specific fields: Example: {nil, :avg_speed\"} or {:lap, :avg_speed}\n- Option to skip CRC calculation\n- Option to skip unknown records or fields\n- Performance - unroll some of the decoding, take a look at how JSON decoders are optimized\n- Helper to convert output to dataframes for usage in smart cells\n- TBD: Replace all floats with Decimals? Probably not, could be done via Processor when needed\n- Wrap in [burrito](https://github.com/burrito-elixir/burrito) and provide CLI\n- LiveBook examples for other sports","ref":"todo.html","title":"TODO","type":"extras"},{"doc":"# Running insights (WIP)\n\n```elixir\nMix.install([\n  {:ext_fit, path: \"./\"},\n  {:kino_maplibre, \"~> 0.1.11\"},\n  {:req, \"~> 0.4.0\"},\n  {:kino_vega_lite, \"~> 0.1.10\"},\n  {:geocalc, \"~> 0.8\"}\n])\n```","ref":"running.html","title":"Running insights (WIP)","type":"extras"},{"doc":"```elixir\nalias ExtFit.{Record, Field}\n\nrecords =\n  \"./test/support/files/2023-06-04-garmin-955-running.fit\"\n  |> File.read!()\n  |> ExtFit.Decode.decode!()\n\nrecord_msgs = Record.records_by_message(records, :record)\n\nIO.puts(\"Decoded #{length(records)} records from FIT file\")\n```","ref":"running.html#fit-decode","title":"FIT Decode - Running insights (WIP)","type":"extras"},{"doc":"```elixir\npoints =\n  record_msgs\n  |> Enum.map(fn record ->\n    with [%{value: plat}] when not is_nil(plat) <- Record.fields_by_name(record, :position_lat),\n         [%{value: plong}] when not is_nil(plat) <- Record.fields_by_name(record, :position_long) do\n      {plong, plat}\n    else\n      _ -> nil\n    end\n  end)\n  |> Enum.filter(&(&1 != nil))\n\npstart = Enum.at(points, 0)\npend = Enum.at(points, -1)\n\nMapLibre.new(\n  center: Geocalc.geographic_center(points),\n  zoom: 10,\n  # key takens from official LiveBook examples, use your own!\n  style: \"https://api.maptiler.com/maps/basic/style.json?key=Q4UbchekCfyvXvZcWRoU\"\n)\n|> MapLibre.add_source(\"route\",\n  type: :geojson,\n  data: [\n    type: \"Feature\",\n    geometry: [\n      type: \"LineString\",\n      coordinates: points\n    ]\n  ]\n)\n|> Kino.MapLibre.add_marker(pstart, color: \"#65a30d\")\n|> Kino.MapLibre.add_marker(pend, color: \"#dc2626\")\n|> MapLibre.add_layer(\n  id: \"route\",\n  type: :line,\n  source: \"route\",\n  layout: [\n    line_join: \"round\",\n    line_cap: \"round\"\n  ],\n  paint: [\n    line_color: \"#f87171\",\n    line_width: 4\n  ]\n)\n|> Kino.MapLibre.new()\n```","ref":"running.html#map-based-on-gps","title":"Map based on GPS - Running insights (WIP)","type":"extras"},{"doc":"```elixir\nalias ExtFit.{Record, Types, Field}\n\nfriendly_name = fn name ->\n  \"#{name}\"\n  |> String.split(\"_\", trim: true)\n  |> Enum.join(\" \")\n  |> String.capitalize()\n  |> String.replace(~r/\\bgps\\b/i, \"GPS\")\n  |> String.replace(~r/\\bhr\\b/i, \"HR\")\n  |> String.replace(~r/\\bpwr\\b/i, \"PWR\")\n  |> String.replace(~r/\\bhrv\\b/i, \"HRV\")\n  |> String.replace(~r/\\bid\\b/i, \"ID\")\n  |> String.replace(~r/\\bcum\\b/i, \"cumulative\")\nend\n\ndrop_headers_without_values = fn headers, records ->\n  headers\n  |> Enum.filter(fn {name, _} ->\n    !!Enum.find(records, &(Map.get(&1, name) != nil))\n  end)\n  |> Enum.into(%{})\nend\n\n# Generate map with msg names as keys and as values, number of records and all matching\n# data for given msg names. In FIT files, the same msg may appear multiple times\n# with different set of fields which makes it more complicated to work with as maps\nsummary =\n  records\n  |> Enum.reduce(%{}, fn\n    %Record.FitData{def_mesg: %{mesg_type: %{} = mesg_type}, fields: fields}, state ->\n      msg_name = to_string(mesg_type.name)\n\n      state =\n        state\n        |> Map.put_new_lazy(msg_name, fn ->\n          %{\n            name: friendly_name.(mesg_type.name),\n            id: msg_name,\n            headers: %{},\n            records_count: 0,\n            records: []\n          }\n        end)\n\n      %{headers: headers} =\n        Enum.reduce(\n          fields,\n          %{\n            headers: get_in(state, [to_string(mesg_type.name), Access.key(:headers)])\n          },\n          fn\n            %Types.FieldData{field: nil}, acc ->\n              acc\n\n            %Types.FieldData{field: %{name: name, units: units}}, %{headers: headers} = acc ->\n              %{\n                acc\n                | headers:\n                    Map.put_new_lazy(headers, name, fn ->\n                      friendly_name.(name) <>\n                        ((units && \" (#{units})\") || \"\")\n                    end)\n              }\n          end\n        )\n\n      state =\n        put_in(state, [to_string(mesg_type.name), :headers], headers)\n\n      record =\n        Enum.reduce(fields, %{}, fn\n          %Types.FieldData{\n            value: value,\n            value_label: value_label,\n            raw_value: raw_value,\n            field: %{name: name, units: units}\n          },\n          record ->\n            value =\n              value_label ||\n                cond do\n                  (units == nil || units in ~w(m)) && is_float(value) ->\n                    Float.round(value, 4)\n\n                  true ->\n                    value || raw_value\n                end\n\n            Map.put(record, name, value)\n\n          _, record ->\n            record\n        end)\n\n      update_in(state, [to_string(mesg_type.name), :records], &[record | &1])\n\n    _, state ->\n      state\n  end)\n  |> Enum.sort_by(&elem(&1, 1).name)\n  |> Enum.map(fn {key, %{records: records, headers: headers} = message} ->\n    headers = drop_headers_without_values.(headers, records)\n\n    {key,\n     %{\n       message\n       | records:\n           Enum.reverse(records)\n           |> Enum.map(fn record ->\n             headers\n             |> Enum.reduce(%{}, fn {name, friendly_name}, new_record ->\n               # ensure every record has all the same keys for all headers\n               # this makes it work nicely with Kino.DataTable\n               Map.put(new_record, name, %{\n                 value: Map.get(record, name) || nil,\n                 name: friendly_name\n               })\n             end)\n           end),\n         records_count: length(records),\n         headers: headers\n     }}\n  end)\n  |> Enum.into(%{})\n```","ref":"running.html#prepare-records-for-dataview","title":"Prepare records for DataView - Running insights (WIP)","type":"extras"},{"doc":"```elixir\nsummary\n|> Enum.map(fn {_, msg} ->\n  rows =\n    msg.records\n    |> Enum.map(fn record ->\n      Enum.map(record, fn {_, %{name: name, value: value}} ->\n        {name, value || \"-\"}\n      end)\n    end)\n\n  {\"#{msg.name} (#{msg.records_count})\", Kino.DataTable.new(rows, sorting_enabled: false)}\nend)\n|> Kino.Layout.tabs()\n```","ref":"running.html#inspect","title":"Inspect - Running insights (WIP)","type":"extras"},{"doc":"```elixir\nalias VegaLite, as: Vl\n\nrecords_dataframe_ =\n  summary[\"record\"].records\n  |> Enum.map(fn record ->\n    Enum.map(record, fn {id, %{value: value}} ->\n      {id, value}\n    end)\n  end)\n\nVl.new(width: 700, height: 300, title: \"HR\")\n|> Vl.data_from_values(records_dataframe_, only: [\"distance\", \"heart_rate\"])\n|> Vl.mark(:point, tooltip: %{content: \"data\"})\n|> Vl.encode_field(:x, \"distance\", type: :quantitative)\n|> Vl.encode_field(:y, \"heart_rate\", type: :quantitative, title: \"HR\")\n|> Vl.encode_field(:color, \"heart_rate\", type: :quantitative)\n```","ref":"running.html#graphs","title":"Graphs! - Running insights (WIP)","type":"extras"}]}